# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon SageMaker"
prefix = "sagemaker"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddAssociation = Action("AddAssociation")
AddTags = Action("AddTags")
AssociateTrialComponent = Action("AssociateTrialComponent")
BatchGetMetrics = Action("BatchGetMetrics")
BatchGetRecord = Action("BatchGetRecord")
BatchPutMetrics = Action("BatchPutMetrics")
CreateAction = Action("CreateAction")
CreateAlgorithm = Action("CreateAlgorithm")
CreateApp = Action("CreateApp")
CreateAppImageConfig = Action("CreateAppImageConfig")
CreateArtifact = Action("CreateArtifact")
CreateAutoMLJob = Action("CreateAutoMLJob")
CreateCodeRepository = Action("CreateCodeRepository")
CreateCompilationJob = Action("CreateCompilationJob")
CreateContext = Action("CreateContext")
CreateDataQualityJobDefinition = Action("CreateDataQualityJobDefinition")
CreateDeviceFleet = Action("CreateDeviceFleet")
CreateDomain = Action("CreateDomain")
CreateEdgePackagingJob = Action("CreateEdgePackagingJob")
CreateEndpoint = Action("CreateEndpoint")
CreateEndpointConfig = Action("CreateEndpointConfig")
CreateExperiment = Action("CreateExperiment")
CreateFeatureGroup = Action("CreateFeatureGroup")
CreateFlowDefinition = Action("CreateFlowDefinition")
CreateHumanTaskUi = Action("CreateHumanTaskUi")
CreateHyperParameterTuningJob = Action("CreateHyperParameterTuningJob")
CreateImage = Action("CreateImage")
CreateImageVersion = Action("CreateImageVersion")
CreateLabelingJob = Action("CreateLabelingJob")
CreateModel = Action("CreateModel")
CreateModelBiasJobDefinition = Action("CreateModelBiasJobDefinition")
CreateModelExplainabilityJobDefinition = Action(
    "CreateModelExplainabilityJobDefinition"
)
CreateModelPackage = Action("CreateModelPackage")
CreateModelPackageGroup = Action("CreateModelPackageGroup")
CreateModelQualityJobDefinition = Action("CreateModelQualityJobDefinition")
CreateMonitoringSchedule = Action("CreateMonitoringSchedule")
CreateNotebookInstance = Action("CreateNotebookInstance")
CreateNotebookInstanceLifecycleConfig = Action("CreateNotebookInstanceLifecycleConfig")
CreatePipeline = Action("CreatePipeline")
CreatePresignedDomainUrl = Action("CreatePresignedDomainUrl")
CreatePresignedNotebookInstanceUrl = Action("CreatePresignedNotebookInstanceUrl")
CreateProcessingJob = Action("CreateProcessingJob")
CreateProject = Action("CreateProject")
CreateTrainingJob = Action("CreateTrainingJob")
CreateTransformJob = Action("CreateTransformJob")
CreateTrial = Action("CreateTrial")
CreateTrialComponent = Action("CreateTrialComponent")
CreateUserProfile = Action("CreateUserProfile")
CreateWorkforce = Action("CreateWorkforce")
CreateWorkteam = Action("CreateWorkteam")
DeleteAction = Action("DeleteAction")
DeleteAlgorithm = Action("DeleteAlgorithm")
DeleteApp = Action("DeleteApp")
DeleteAppImageConfig = Action("DeleteAppImageConfig")
DeleteArtifact = Action("DeleteArtifact")
DeleteAssociation = Action("DeleteAssociation")
DeleteCodeRepository = Action("DeleteCodeRepository")
DeleteContext = Action("DeleteContext")
DeleteDataQualityJobDefinition = Action("DeleteDataQualityJobDefinition")
DeleteDeviceFleet = Action("DeleteDeviceFleet")
DeleteDomain = Action("DeleteDomain")
DeleteEndpoint = Action("DeleteEndpoint")
DeleteEndpointConfig = Action("DeleteEndpointConfig")
DeleteExperiment = Action("DeleteExperiment")
DeleteFeatureGroup = Action("DeleteFeatureGroup")
DeleteFlowDefinition = Action("DeleteFlowDefinition")
DeleteHumanLoop = Action("DeleteHumanLoop")
DeleteHumanTaskUi = Action("DeleteHumanTaskUi")
DeleteImage = Action("DeleteImage")
DeleteImageVersion = Action("DeleteImageVersion")
DeleteModel = Action("DeleteModel")
DeleteModelBiasJobDefinition = Action("DeleteModelBiasJobDefinition")
DeleteModelExplainabilityJobDefinition = Action(
    "DeleteModelExplainabilityJobDefinition"
)
DeleteModelPackage = Action("DeleteModelPackage")
DeleteModelPackageGroup = Action("DeleteModelPackageGroup")
DeleteModelPackageGroupPolicy = Action("DeleteModelPackageGroupPolicy")
DeleteModelQualityJobDefinition = Action("DeleteModelQualityJobDefinition")
DeleteMonitoringSchedule = Action("DeleteMonitoringSchedule")
DeleteNotebookInstance = Action("DeleteNotebookInstance")
DeleteNotebookInstanceLifecycleConfig = Action("DeleteNotebookInstanceLifecycleConfig")
DeletePipeline = Action("DeletePipeline")
DeleteProject = Action("DeleteProject")
DeleteRecord = Action("DeleteRecord")
DeleteTags = Action("DeleteTags")
DeleteTrial = Action("DeleteTrial")
DeleteTrialComponent = Action("DeleteTrialComponent")
DeleteUserProfile = Action("DeleteUserProfile")
DeleteWorkforce = Action("DeleteWorkforce")
DeleteWorkteam = Action("DeleteWorkteam")
DeregisterDevices = Action("DeregisterDevices")
DescribeAction = Action("DescribeAction")
DescribeAlgorithm = Action("DescribeAlgorithm")
DescribeApp = Action("DescribeApp")
DescribeAppImageConfig = Action("DescribeAppImageConfig")
DescribeArtifact = Action("DescribeArtifact")
DescribeAutoMLJob = Action("DescribeAutoMLJob")
DescribeCodeRepository = Action("DescribeCodeRepository")
DescribeCompilationJob = Action("DescribeCompilationJob")
DescribeContext = Action("DescribeContext")
DescribeDataQualityJobDefinition = Action("DescribeDataQualityJobDefinition")
DescribeDevice = Action("DescribeDevice")
DescribeDeviceFleet = Action("DescribeDeviceFleet")
DescribeDomain = Action("DescribeDomain")
DescribeEdgePackagingJob = Action("DescribeEdgePackagingJob")
DescribeEndpoint = Action("DescribeEndpoint")
DescribeEndpointConfig = Action("DescribeEndpointConfig")
DescribeExperiment = Action("DescribeExperiment")
DescribeFeatureGroup = Action("DescribeFeatureGroup")
DescribeFlowDefinition = Action("DescribeFlowDefinition")
DescribeHumanLoop = Action("DescribeHumanLoop")
DescribeHumanTaskUi = Action("DescribeHumanTaskUi")
DescribeHyperParameterTuningJob = Action("DescribeHyperParameterTuningJob")
DescribeImage = Action("DescribeImage")
DescribeImageVersion = Action("DescribeImageVersion")
DescribeLabelingJob = Action("DescribeLabelingJob")
DescribeModel = Action("DescribeModel")
DescribeModelBiasJobDefinition = Action("DescribeModelBiasJobDefinition")
DescribeModelExplainabilityJobDefinition = Action(
    "DescribeModelExplainabilityJobDefinition"
)
DescribeModelPackage = Action("DescribeModelPackage")
DescribeModelPackageGroup = Action("DescribeModelPackageGroup")
DescribeModelQualityJobDefinition = Action("DescribeModelQualityJobDefinition")
DescribeMonitoringSchedule = Action("DescribeMonitoringSchedule")
DescribeNotebookInstance = Action("DescribeNotebookInstance")
DescribeNotebookInstanceLifecycleConfig = Action(
    "DescribeNotebookInstanceLifecycleConfig"
)
DescribePipeline = Action("DescribePipeline")
DescribePipelineDefinitionForExecution = Action(
    "DescribePipelineDefinitionForExecution"
)
DescribePipelineExecution = Action("DescribePipelineExecution")
DescribeProcessingJob = Action("DescribeProcessingJob")
DescribeProject = Action("DescribeProject")
DescribeSubscribedWorkteam = Action("DescribeSubscribedWorkteam")
DescribeTrainingJob = Action("DescribeTrainingJob")
DescribeTransformJob = Action("DescribeTransformJob")
DescribeTrial = Action("DescribeTrial")
DescribeTrialComponent = Action("DescribeTrialComponent")
DescribeUserProfile = Action("DescribeUserProfile")
DescribeWorkforce = Action("DescribeWorkforce")
DescribeWorkteam = Action("DescribeWorkteam")
DisableSagemakerServicecatalogPortfolio = Action(
    "DisableSagemakerServicecatalogPortfolio"
)
DisassociateTrialComponent = Action("DisassociateTrialComponent")
EnableSagemakerServicecatalogPortfolio = Action(
    "EnableSagemakerServicecatalogPortfolio"
)
GetDeviceFleetReport = Action("GetDeviceFleetReport")
GetDeviceRegistration = Action("GetDeviceRegistration")
GetModelPackageGroupPolicy = Action("GetModelPackageGroupPolicy")
GetRecord = Action("GetRecord")
GetSagemakerServicecatalogPortfolioStatus = Action(
    "GetSagemakerServicecatalogPortfolioStatus"
)
GetSearchSuggestions = Action("GetSearchSuggestions")
InvokeEndpoint = Action("InvokeEndpoint")
InvokeEndpointAsync = Action("InvokeEndpointAsync")
ListActions = Action("ListActions")
ListAlgorithms = Action("ListAlgorithms")
ListAppImageConfigs = Action("ListAppImageConfigs")
ListApps = Action("ListApps")
ListArtifacts = Action("ListArtifacts")
ListAssociations = Action("ListAssociations")
ListAutoMLJobs = Action("ListAutoMLJobs")
ListCandidatesForAutoMLJob = Action("ListCandidatesForAutoMLJob")
ListCodeRepositories = Action("ListCodeRepositories")
ListCompilationJobs = Action("ListCompilationJobs")
ListContexts = Action("ListContexts")
ListDataQualityJobDefinitions = Action("ListDataQualityJobDefinitions")
ListDeviceFleets = Action("ListDeviceFleets")
ListDevices = Action("ListDevices")
ListDomains = Action("ListDomains")
ListEdgePackagingJobs = Action("ListEdgePackagingJobs")
ListEndpointConfigs = Action("ListEndpointConfigs")
ListEndpoints = Action("ListEndpoints")
ListExperiments = Action("ListExperiments")
ListFeatureGroups = Action("ListFeatureGroups")
ListFlowDefinitions = Action("ListFlowDefinitions")
ListHumanLoops = Action("ListHumanLoops")
ListHumanTaskUis = Action("ListHumanTaskUis")
ListHyperParameterTuningJobs = Action("ListHyperParameterTuningJobs")
ListImageVersions = Action("ListImageVersions")
ListImages = Action("ListImages")
ListLabelingJobs = Action("ListLabelingJobs")
ListLabelingJobsForWorkteam = Action("ListLabelingJobsForWorkteam")
ListModelBiasJobDefinitions = Action("ListModelBiasJobDefinitions")
ListModelExplainabilityJobDefinitions = Action("ListModelExplainabilityJobDefinitions")
ListModelPackageGroups = Action("ListModelPackageGroups")
ListModelPackages = Action("ListModelPackages")
ListModelQualityJobDefinitions = Action("ListModelQualityJobDefinitions")
ListModels = Action("ListModels")
ListMonitoringExecutions = Action("ListMonitoringExecutions")
ListMonitoringSchedules = Action("ListMonitoringSchedules")
ListNotebookInstanceLifecycleConfigs = Action("ListNotebookInstanceLifecycleConfigs")
ListNotebookInstances = Action("ListNotebookInstances")
ListPipelineExecutionSteps = Action("ListPipelineExecutionSteps")
ListPipelineExecutions = Action("ListPipelineExecutions")
ListPipelineParametersForExecution = Action("ListPipelineParametersForExecution")
ListPipelines = Action("ListPipelines")
ListProcessingJobs = Action("ListProcessingJobs")
ListProjects = Action("ListProjects")
ListSubscribedWorkteams = Action("ListSubscribedWorkteams")
ListTags = Action("ListTags")
ListTrainingJobs = Action("ListTrainingJobs")
ListTrainingJobsForHyperParameterTuningJob = Action(
    "ListTrainingJobsForHyperParameterTuningJob"
)
ListTransformJobs = Action("ListTransformJobs")
ListTrialComponents = Action("ListTrialComponents")
ListTrials = Action("ListTrials")
ListUserProfiles = Action("ListUserProfiles")
ListWorkforces = Action("ListWorkforces")
ListWorkteams = Action("ListWorkteams")
PutModelPackageGroupPolicy = Action("PutModelPackageGroupPolicy")
PutRecord = Action("PutRecord")
RegisterDevices = Action("RegisterDevices")
RenderUiTemplate = Action("RenderUiTemplate")
Search = Action("Search")
SendHeartbeat = Action("SendHeartbeat")
SendPipelineExecutionStepFailure = Action("SendPipelineExecutionStepFailure")
SendPipelineExecutionStepSuccess = Action("SendPipelineExecutionStepSuccess")
StartHumanLoop = Action("StartHumanLoop")
StartMonitoringSchedule = Action("StartMonitoringSchedule")
StartNotebookInstance = Action("StartNotebookInstance")
StartPipelineExecution = Action("StartPipelineExecution")
StopAutoMLJob = Action("StopAutoMLJob")
StopCompilationJob = Action("StopCompilationJob")
StopEdgePackagingJob = Action("StopEdgePackagingJob")
StopHumanLoop = Action("StopHumanLoop")
StopHyperParameterTuningJob = Action("StopHyperParameterTuningJob")
StopLabelingJob = Action("StopLabelingJob")
StopMonitoringSchedule = Action("StopMonitoringSchedule")
StopNotebookInstance = Action("StopNotebookInstance")
StopPipelineExecution = Action("StopPipelineExecution")
StopProcessingJob = Action("StopProcessingJob")
StopTrainingJob = Action("StopTrainingJob")
StopTransformJob = Action("StopTransformJob")
UpdateAction = Action("UpdateAction")
UpdateAppImageConfig = Action("UpdateAppImageConfig")
UpdateArtifact = Action("UpdateArtifact")
UpdateCodeRepository = Action("UpdateCodeRepository")
UpdateContext = Action("UpdateContext")
UpdateDeviceFleet = Action("UpdateDeviceFleet")
UpdateDevices = Action("UpdateDevices")
UpdateDomain = Action("UpdateDomain")
UpdateEndpoint = Action("UpdateEndpoint")
UpdateEndpointWeightsAndCapacities = Action("UpdateEndpointWeightsAndCapacities")
UpdateExperiment = Action("UpdateExperiment")
UpdateImage = Action("UpdateImage")
UpdateModelPackage = Action("UpdateModelPackage")
UpdateMonitoringSchedule = Action("UpdateMonitoringSchedule")
UpdateNotebookInstance = Action("UpdateNotebookInstance")
UpdateNotebookInstanceLifecycleConfig = Action("UpdateNotebookInstanceLifecycleConfig")
UpdatePipeline = Action("UpdatePipeline")
UpdatePipelineExecution = Action("UpdatePipelineExecution")
UpdateTrainingJob = Action("UpdateTrainingJob")
UpdateTrial = Action("UpdateTrial")
UpdateTrialComponent = Action("UpdateTrialComponent")
UpdateUserProfile = Action("UpdateUserProfile")
UpdateWorkforce = Action("UpdateWorkforce")
UpdateWorkteam = Action("UpdateWorkteam")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic Container Registry Public"
prefix = "ecr-public"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchCheckLayerAvailability = Action("BatchCheckLayerAvailability")
BatchDeleteImage = Action("BatchDeleteImage")
CompleteLayerUpload = Action("CompleteLayerUpload")
CreateRepository = Action("CreateRepository")
DeleteRepository = Action("DeleteRepository")
DeleteRepositoryPolicy = Action("DeleteRepositoryPolicy")
DescribeImageTags = Action("DescribeImageTags")
DescribeImages = Action("DescribeImages")
DescribeRegistries = Action("DescribeRegistries")
DescribeRepositories = Action("DescribeRepositories")
GetAuthorizationToken = Action("GetAuthorizationToken")
GetRegistryCatalogData = Action("GetRegistryCatalogData")
GetRepositoryCatalogData = Action("GetRepositoryCatalogData")
GetRepositoryPolicy = Action("GetRepositoryPolicy")
InitiateLayerUpload = Action("InitiateLayerUpload")
ListTagsForResource = Action("ListTagsForResource")
PutImage = Action("PutImage")
PutRegistryCatalogData = Action("PutRegistryCatalogData")
PutRepositoryCatalogData = Action("PutRepositoryCatalogData")
SetRepositoryPolicy = Action("SetRepositoryPolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UploadLayerPart = Action("UploadLayerPart")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Cognito User Pools"
prefix = "cognito-idp"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddCustomAttributes = Action("AddCustomAttributes")
AdminAddUserToGroup = Action("AdminAddUserToGroup")
AdminConfirmSignUp = Action("AdminConfirmSignUp")
AdminCreateUser = Action("AdminCreateUser")
AdminDeleteUser = Action("AdminDeleteUser")
AdminDeleteUserAttributes = Action("AdminDeleteUserAttributes")
AdminDisableProviderForUser = Action("AdminDisableProviderForUser")
AdminDisableUser = Action("AdminDisableUser")
AdminEnableUser = Action("AdminEnableUser")
AdminForgetDevice = Action("AdminForgetDevice")
AdminGetDevice = Action("AdminGetDevice")
AdminGetUser = Action("AdminGetUser")
AdminInitiateAuth = Action("AdminInitiateAuth")
AdminLinkProviderForUser = Action("AdminLinkProviderForUser")
AdminListDevices = Action("AdminListDevices")
AdminListGroupsForUser = Action("AdminListGroupsForUser")
AdminListUserAuthEvents = Action("AdminListUserAuthEvents")
AdminRemoveUserFromGroup = Action("AdminRemoveUserFromGroup")
AdminResetUserPassword = Action("AdminResetUserPassword")
AdminRespondToAuthChallenge = Action("AdminRespondToAuthChallenge")
AdminSetUserMFAPreference = Action("AdminSetUserMFAPreference")
AdminSetUserPassword = Action("AdminSetUserPassword")
AdminSetUserSettings = Action("AdminSetUserSettings")
AdminUpdateAuthEventFeedback = Action("AdminUpdateAuthEventFeedback")
AdminUpdateDeviceStatus = Action("AdminUpdateDeviceStatus")
AdminUpdateUserAttributes = Action("AdminUpdateUserAttributes")
AdminUserGlobalSignOut = Action("AdminUserGlobalSignOut")
AssociateSoftwareToken = Action("AssociateSoftwareToken")
ChangePassword = Action("ChangePassword")
ConfirmDevice = Action("ConfirmDevice")
ConfirmForgotPassword = Action("ConfirmForgotPassword")
ConfirmSignUp = Action("ConfirmSignUp")
CreateGroup = Action("CreateGroup")
CreateIdentityProvider = Action("CreateIdentityProvider")
CreateResourceServer = Action("CreateResourceServer")
CreateUserImportJob = Action("CreateUserImportJob")
CreateUserPool = Action("CreateUserPool")
CreateUserPoolClient = Action("CreateUserPoolClient")
CreateUserPoolDomain = Action("CreateUserPoolDomain")
DeleteGroup = Action("DeleteGroup")
DeleteIdentityProvider = Action("DeleteIdentityProvider")
DeleteResourceServer = Action("DeleteResourceServer")
DeleteUser = Action("DeleteUser")
DeleteUserAttributes = Action("DeleteUserAttributes")
DeleteUserPool = Action("DeleteUserPool")
DeleteUserPoolClient = Action("DeleteUserPoolClient")
DeleteUserPoolDomain = Action("DeleteUserPoolDomain")
DescribeIdentityProvider = Action("DescribeIdentityProvider")
DescribeResourceServer = Action("DescribeResourceServer")
DescribeRiskConfiguration = Action("DescribeRiskConfiguration")
DescribeUserImportJob = Action("DescribeUserImportJob")
DescribeUserPool = Action("DescribeUserPool")
DescribeUserPoolClient = Action("DescribeUserPoolClient")
DescribeUserPoolDomain = Action("DescribeUserPoolDomain")
ForgetDevice = Action("ForgetDevice")
ForgotPassword = Action("ForgotPassword")
GetCSVHeader = Action("GetCSVHeader")
GetDevice = Action("GetDevice")
GetGroup = Action("GetGroup")
GetIdentityProviderByIdentifier = Action("GetIdentityProviderByIdentifier")
GetSigningCertificate = Action("GetSigningCertificate")
GetUICustomization = Action("GetUICustomization")
GetUser = Action("GetUser")
GetUserAttributeVerificationCode = Action("GetUserAttributeVerificationCode")
GetUserPoolMfaConfig = Action("GetUserPoolMfaConfig")
GlobalSignOut = Action("GlobalSignOut")
InitiateAuth = Action("InitiateAuth")
ListDevices = Action("ListDevices")
ListGroups = Action("ListGroups")
ListIdentityProviders = Action("ListIdentityProviders")
ListResourceServers = Action("ListResourceServers")
ListTagsForResource = Action("ListTagsForResource")
ListUserImportJobs = Action("ListUserImportJobs")
ListUserPoolClients = Action("ListUserPoolClients")
ListUserPools = Action("ListUserPools")
ListUsers = Action("ListUsers")
ListUsersInGroup = Action("ListUsersInGroup")
ResendConfirmationCode = Action("ResendConfirmationCode")
RespondToAuthChallenge = Action("RespondToAuthChallenge")
SetRiskConfiguration = Action("SetRiskConfiguration")
SetUICustomization = Action("SetUICustomization")
SetUserMFAPreference = Action("SetUserMFAPreference")
SetUserPoolMfaConfig = Action("SetUserPoolMfaConfig")
SetUserSettings = Action("SetUserSettings")
SignUp = Action("SignUp")
StartUserImportJob = Action("StartUserImportJob")
StopUserImportJob = Action("StopUserImportJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAuthEventFeedback = Action("UpdateAuthEventFeedback")
UpdateDeviceStatus = Action("UpdateDeviceStatus")
UpdateGroup = Action("UpdateGroup")
UpdateIdentityProvider = Action("UpdateIdentityProvider")
UpdateResourceServer = Action("UpdateResourceServer")
UpdateUserAttributes = Action("UpdateUserAttributes")
UpdateUserPool = Action("UpdateUserPool")
UpdateUserPoolClient = Action("UpdateUserPoolClient")
UpdateUserPoolDomain = Action("UpdateUserPoolDomain")
VerifySoftwareToken = Action("VerifySoftwareToken")
VerifyUserAttribute = Action("VerifyUserAttribute")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Security Token Service"
prefix = "sts"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssumeRole = Action("AssumeRole")
AssumeRoleWithSAML = Action("AssumeRoleWithSAML")
AssumeRoleWithWebIdentity = Action("AssumeRoleWithWebIdentity")
DecodeAuthorizationMessage = Action("DecodeAuthorizationMessage")
GetAccessKeyInfo = Action("GetAccessKeyInfo")
GetCallerIdentity = Action("GetCallerIdentity")
GetFederationToken = Action("GetFederationToken")
GetServiceBearerToken = Action("GetServiceBearerToken")
GetSessionToken = Action("GetSessionToken")
SetSourceIdentity = Action("SetSourceIdentity")
TagSession = Action("TagSession")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Cognito Sync"
prefix = "cognito-sync"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BulkPublish = Action("BulkPublish")
DeleteDataset = Action("DeleteDataset")
DescribeDataset = Action("DescribeDataset")
DescribeIdentityPoolUsage = Action("DescribeIdentityPoolUsage")
DescribeIdentityUsage = Action("DescribeIdentityUsage")
GetBulkPublishDetails = Action("GetBulkPublishDetails")
GetCognitoEvents = Action("GetCognitoEvents")
GetIdentityPoolConfiguration = Action("GetIdentityPoolConfiguration")
ListDatasets = Action("ListDatasets")
ListIdentityPoolUsage = Action("ListIdentityPoolUsage")
ListRecords = Action("ListRecords")
QueryRecords = Action("QueryRecords")
RegisterDevice = Action("RegisterDevice")
SetCognitoEvents = Action("SetCognitoEvents")
SetDatasetConfiguration = Action("SetDatasetConfiguration")
SetIdentityPoolConfiguration = Action("SetIdentityPoolConfiguration")
SubscribeToDataset = Action("SubscribeToDataset")
UnsubscribeFromDataset = Action("UnsubscribeFromDataset")
UpdateRecords = Action("UpdateRecords")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS SSO Directory"
prefix = "sso-directory"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddMemberToGroup = Action("AddMemberToGroup")
CompleteVirtualMfaDeviceRegistration = Action("CompleteVirtualMfaDeviceRegistration")
CompleteWebAuthnDeviceRegistration = Action("CompleteWebAuthnDeviceRegistration")
CreateAlias = Action("CreateAlias")
CreateBearerToken = Action("CreateBearerToken")
CreateExternalIdPConfigurationForDirectory = Action(
    "CreateExternalIdPConfigurationForDirectory"
)
CreateGroup = Action("CreateGroup")
CreateProvisioningTenant = Action("CreateProvisioningTenant")
CreateUser = Action("CreateUser")
DeleteBearerToken = Action("DeleteBearerToken")
DeleteExternalIdPCertificate = Action("DeleteExternalIdPCertificate")
DeleteExternalIdPConfigurationForDirectory = Action(
    "DeleteExternalIdPConfigurationForDirectory"
)
DeleteGroup = Action("DeleteGroup")
DeleteMfaDeviceForUser = Action("DeleteMfaDeviceForUser")
DeleteProvisioningTenant = Action("DeleteProvisioningTenant")
DeleteUser = Action("DeleteUser")
DescribeDirectory = Action("DescribeDirectory")
DescribeGroup = Action("DescribeGroup")
DescribeGroups = Action("DescribeGroups")
DescribeProvisioningTenant = Action("DescribeProvisioningTenant")
DescribeUser = Action("DescribeUser")
DescribeUserByUniqueAttribute = Action("DescribeUserByUniqueAttribute")
DescribeUsers = Action("DescribeUsers")
DisableExternalIdPConfigurationForDirectory = Action(
    "DisableExternalIdPConfigurationForDirectory"
)
DisableUser = Action("DisableUser")
EnableExternalIdPConfigurationForDirectory = Action(
    "EnableExternalIdPConfigurationForDirectory"
)
EnableUser = Action("EnableUser")
GetAWSSPConfigurationForDirectory = Action("GetAWSSPConfigurationForDirectory")
GetUserPoolInfo = Action("GetUserPoolInfo")
ImportExternalIdPCertificate = Action("ImportExternalIdPCertificate")
IsMemberInGroup = Action("IsMemberInGroup")
ListBearerTokens = Action("ListBearerTokens")
ListExternalIdPCertificates = Action("ListExternalIdPCertificates")
ListExternalIdPConfigurationsForDirectory = Action(
    "ListExternalIdPConfigurationsForDirectory"
)
ListGroupsForMember = Action("ListGroupsForMember")
ListGroupsForUser = Action("ListGroupsForUser")
ListMembersInGroup = Action("ListMembersInGroup")
ListMfaDevicesForUser = Action("ListMfaDevicesForUser")
ListProvisioningTenants = Action("ListProvisioningTenants")
RemoveMemberFromGroup = Action("RemoveMemberFromGroup")
SearchGroups = Action("SearchGroups")
SearchUsers = Action("SearchUsers")
StartVirtualMfaDeviceRegistration = Action("StartVirtualMfaDeviceRegistration")
StartWebAuthnDeviceRegistration = Action("StartWebAuthnDeviceRegistration")
UpdateExternalIdPConfigurationForDirectory = Action(
    "UpdateExternalIdPConfigurationForDirectory"
)
UpdateGroup = Action("UpdateGroup")
UpdateGroupDisplayName = Action("UpdateGroupDisplayName")
UpdateMfaDeviceForUser = Action("UpdateMfaDeviceForUser")
UpdatePassword = Action("UpdatePassword")
UpdateUser = Action("UpdateUser")
UpdateUserName = Action("UpdateUserName")
VerifyEmail = Action("VerifyEmail")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Managed Blockchain"
prefix = "managedblockchain"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateMember = Action("CreateMember")
CreateNetwork = Action("CreateNetwork")
CreateNode = Action("CreateNode")
CreateProposal = Action("CreateProposal")
DeleteMember = Action("DeleteMember")
DeleteNode = Action("DeleteNode")
GetMember = Action("GetMember")
GetNetwork = Action("GetNetwork")
GetNode = Action("GetNode")
GetProposal = Action("GetProposal")
ListInvitations = Action("ListInvitations")
ListMembers = Action("ListMembers")
ListNetworks = Action("ListNetworks")
ListNodes = Action("ListNodes")
ListProposalVotes = Action("ListProposalVotes")
ListProposals = Action("ListProposals")
ListTagsForResource = Action("ListTagsForResource")
RejectInvitation = Action("RejectInvitation")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateMember = Action("UpdateMember")
UpdateNode = Action("UpdateNode")
VoteOnProposal = Action("VoteOnProposal")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Transfer Family"
prefix = "transfer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateAccess = Action("CreateAccess")
CreateServer = Action("CreateServer")
CreateUser = Action("CreateUser")
CreateWorkflow = Action("CreateWorkflow")
DeleteAccess = Action("DeleteAccess")
DeleteServer = Action("DeleteServer")
DeleteSshPublicKey = Action("DeleteSshPublicKey")
DeleteUser = Action("DeleteUser")
DeleteWorkflow = Action("DeleteWorkflow")
DescribeAccess = Action("DescribeAccess")
DescribeExecution = Action("DescribeExecution")
DescribeSecurityPolicy = Action("DescribeSecurityPolicy")
DescribeServer = Action("DescribeServer")
DescribeUser = Action("DescribeUser")
DescribeWorkflow = Action("DescribeWorkflow")
ImportSshPublicKey = Action("ImportSshPublicKey")
ListAccesses = Action("ListAccesses")
ListExecutions = Action("ListExecutions")
ListSecurityPolicies = Action("ListSecurityPolicies")
ListServers = Action("ListServers")
ListTagsForResource = Action("ListTagsForResource")
ListUsers = Action("ListUsers")
ListWorkflows = Action("ListWorkflows")
SendWorkflowStepState = Action("SendWorkflowStepState")
StartServer = Action("StartServer")
StopServer = Action("StopServer")
TagResource = Action("TagResource")
TestIdentityProvider = Action("TestIdentityProvider")
UntagResource = Action("UntagResource")
UpdateAccess = Action("UpdateAccess")
UpdateServer = Action("UpdateServer")
UpdateUser = Action("UpdateUser")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Glue"
prefix = "glue"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchCreatePartition = Action("BatchCreatePartition")
BatchDeleteConnection = Action("BatchDeleteConnection")
BatchDeletePartition = Action("BatchDeletePartition")
BatchDeleteTable = Action("BatchDeleteTable")
BatchDeleteTableVersion = Action("BatchDeleteTableVersion")
BatchGetCrawlers = Action("BatchGetCrawlers")
BatchGetDevEndpoints = Action("BatchGetDevEndpoints")
BatchGetJobs = Action("BatchGetJobs")
BatchGetPartition = Action("BatchGetPartition")
BatchGetTriggers = Action("BatchGetTriggers")
BatchGetWorkflows = Action("BatchGetWorkflows")
BatchStopJobRun = Action("BatchStopJobRun")
CancelMLTaskRun = Action("CancelMLTaskRun")
CheckSchemaVersionValidity = Action("CheckSchemaVersionValidity")
CreateClassifier = Action("CreateClassifier")
CreateConnection = Action("CreateConnection")
CreateCrawler = Action("CreateCrawler")
CreateDatabase = Action("CreateDatabase")
CreateDevEndpoint = Action("CreateDevEndpoint")
CreateJob = Action("CreateJob")
CreateMLTransform = Action("CreateMLTransform")
CreatePartition = Action("CreatePartition")
CreateRegistry = Action("CreateRegistry")
CreateSchema = Action("CreateSchema")
CreateScript = Action("CreateScript")
CreateSecurityConfiguration = Action("CreateSecurityConfiguration")
CreateTable = Action("CreateTable")
CreateTrigger = Action("CreateTrigger")
CreateUserDefinedFunction = Action("CreateUserDefinedFunction")
CreateWorkflow = Action("CreateWorkflow")
DeleteClassifier = Action("DeleteClassifier")
DeleteConnection = Action("DeleteConnection")
DeleteCrawler = Action("DeleteCrawler")
DeleteDatabase = Action("DeleteDatabase")
DeleteDevEndpoint = Action("DeleteDevEndpoint")
DeleteJob = Action("DeleteJob")
DeleteMLTransform = Action("DeleteMLTransform")
DeletePartition = Action("DeletePartition")
DeleteRegistry = Action("DeleteRegistry")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSchema = Action("DeleteSchema")
DeleteSchemaVersions = Action("DeleteSchemaVersions")
DeleteSecurityConfiguration = Action("DeleteSecurityConfiguration")
DeleteTable = Action("DeleteTable")
DeleteTableVersion = Action("DeleteTableVersion")
DeleteTrigger = Action("DeleteTrigger")
DeleteUserDefinedFunction = Action("DeleteUserDefinedFunction")
DeleteWorkflow = Action("DeleteWorkflow")
GetCatalogImportStatus = Action("GetCatalogImportStatus")
GetClassifier = Action("GetClassifier")
GetClassifiers = Action("GetClassifiers")
GetConnection = Action("GetConnection")
GetConnections = Action("GetConnections")
GetCrawler = Action("GetCrawler")
GetCrawlerMetrics = Action("GetCrawlerMetrics")
GetCrawlers = Action("GetCrawlers")
GetDataCatalogEncryptionSettings = Action("GetDataCatalogEncryptionSettings")
GetDatabase = Action("GetDatabase")
GetDatabases = Action("GetDatabases")
GetDataflowGraph = Action("GetDataflowGraph")
GetDevEndpoint = Action("GetDevEndpoint")
GetDevEndpoints = Action("GetDevEndpoints")
GetJob = Action("GetJob")
GetJobBookmark = Action("GetJobBookmark")
GetJobRun = Action("GetJobRun")
GetJobRuns = Action("GetJobRuns")
GetJobs = Action("GetJobs")
GetMLTaskRun = Action("GetMLTaskRun")
GetMLTaskRuns = Action("GetMLTaskRuns")
GetMLTransform = Action("GetMLTransform")
GetMLTransforms = Action("GetMLTransforms")
GetMapping = Action("GetMapping")
GetPartition = Action("GetPartition")
GetPartitions = Action("GetPartitions")
GetPlan = Action("GetPlan")
GetRegistry = Action("GetRegistry")
GetResourcePolicies = Action("GetResourcePolicies")
GetResourcePolicy = Action("GetResourcePolicy")
GetSchema = Action("GetSchema")
GetSchemaByDefinition = Action("GetSchemaByDefinition")
GetSchemaVersion = Action("GetSchemaVersion")
GetSchemaVersionsDiff = Action("GetSchemaVersionsDiff")
GetSecurityConfiguration = Action("GetSecurityConfiguration")
GetSecurityConfigurations = Action("GetSecurityConfigurations")
GetTable = Action("GetTable")
GetTableVersion = Action("GetTableVersion")
GetTableVersions = Action("GetTableVersions")
GetTables = Action("GetTables")
GetTags = Action("GetTags")
GetTrigger = Action("GetTrigger")
GetTriggers = Action("GetTriggers")
GetUserDefinedFunction = Action("GetUserDefinedFunction")
GetUserDefinedFunctions = Action("GetUserDefinedFunctions")
GetWorkflow = Action("GetWorkflow")
GetWorkflowRun = Action("GetWorkflowRun")
GetWorkflowRunProperties = Action("GetWorkflowRunProperties")
GetWorkflowRuns = Action("GetWorkflowRuns")
ImportCatalogToGlue = Action("ImportCatalogToGlue")
ListCrawlers = Action("ListCrawlers")
ListDevEndpoints = Action("ListDevEndpoints")
ListJobs = Action("ListJobs")
ListMLTransforms = Action("ListMLTransforms")
ListRegistries = Action("ListRegistries")
ListSchemaVersions = Action("ListSchemaVersions")
ListSchemas = Action("ListSchemas")
ListTriggers = Action("ListTriggers")
ListWorkflows = Action("ListWorkflows")
NotifyEvent = Action("NotifyEvent")
PutDataCatalogEncryptionSettings = Action("PutDataCatalogEncryptionSettings")
PutResourcePolicy = Action("PutResourcePolicy")
PutSchemaVersionMetadata = Action("PutSchemaVersionMetadata")
PutWorkflowRunProperties = Action("PutWorkflowRunProperties")
QuerySchemaVersionMetadata = Action("QuerySchemaVersionMetadata")
RegisterSchemaVersion = Action("RegisterSchemaVersion")
RemoveSchemaVersionMetadata = Action("RemoveSchemaVersionMetadata")
ResetJobBookmark = Action("ResetJobBookmark")
ResumeWorkflowRun = Action("ResumeWorkflowRun")
SearchTables = Action("SearchTables")
StartCrawler = Action("StartCrawler")
StartCrawlerSchedule = Action("StartCrawlerSchedule")
StartExportLabelsTaskRun = Action("StartExportLabelsTaskRun")
StartImportLabelsTaskRun = Action("StartImportLabelsTaskRun")
StartJobRun = Action("StartJobRun")
StartMLEvaluationTaskRun = Action("StartMLEvaluationTaskRun")
StartMLLabelingSetGenerationTaskRun = Action("StartMLLabelingSetGenerationTaskRun")
StartTrigger = Action("StartTrigger")
StartWorkflowRun = Action("StartWorkflowRun")
StopCrawler = Action("StopCrawler")
StopCrawlerSchedule = Action("StopCrawlerSchedule")
StopTrigger = Action("StopTrigger")
StopWorkflowRun = Action("StopWorkflowRun")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateClassifier = Action("UpdateClassifier")
UpdateConnection = Action("UpdateConnection")
UpdateCrawler = Action("UpdateCrawler")
UpdateCrawlerSchedule = Action("UpdateCrawlerSchedule")
UpdateDatabase = Action("UpdateDatabase")
UpdateDevEndpoint = Action("UpdateDevEndpoint")
UpdateJob = Action("UpdateJob")
UpdateMLTransform = Action("UpdateMLTransform")
UpdatePartition = Action("UpdatePartition")
UpdateRegistry = Action("UpdateRegistry")
UpdateSchema = Action("UpdateSchema")
UpdateTable = Action("UpdateTable")
UpdateTrigger = Action("UpdateTrigger")
UpdateUserDefinedFunction = Action("UpdateUserDefinedFunction")
UpdateWorkflow = Action("UpdateWorkflow")
UseMLTransforms = Action("UseMLTransforms")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CloudWatch Synthetics"
prefix = "synthetics"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCanary = Action("CreateCanary")
DeleteCanary = Action("DeleteCanary")
DescribeCanaries = Action("DescribeCanaries")
DescribeCanariesLastRun = Action("DescribeCanariesLastRun")
DescribeRuntimeVersions = Action("DescribeRuntimeVersions")
GetCanary = Action("GetCanary")
GetCanaryRuns = Action("GetCanaryRuns")
ListTagsForResource = Action("ListTagsForResource")
StartCanary = Action("StartCanary")
StopCanary = Action("StopCanary")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateCanary = Action("UpdateCanary")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS DeepLens"
prefix = "deeplens"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateServiceRoleToAccount = Action("AssociateServiceRoleToAccount")
BatchGetDevice = Action("BatchGetDevice")
BatchGetModel = Action("BatchGetModel")
BatchGetProject = Action("BatchGetProject")
CreateDeviceCertificates = Action("CreateDeviceCertificates")
CreateModel = Action("CreateModel")
CreateProject = Action("CreateProject")
DeleteModel = Action("DeleteModel")
DeleteProject = Action("DeleteProject")
DeployProject = Action("DeployProject")
DeregisterDevice = Action("DeregisterDevice")
GetAssociatedResources = Action("GetAssociatedResources")
GetDeploymentStatus = Action("GetDeploymentStatus")
GetDevice = Action("GetDevice")
GetModel = Action("GetModel")
GetProject = Action("GetProject")
ImportProjectFromTemplate = Action("ImportProjectFromTemplate")
ListDeployments = Action("ListDeployments")
ListDevices = Action("ListDevices")
ListModels = Action("ListModels")
ListProjects = Action("ListProjects")
RegisterDevice = Action("RegisterDevice")
RemoveProject = Action("RemoveProject")
UpdateProject = Action("UpdateProject")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Firewall Manager"
prefix = "fms"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateAdminAccount = Action("AssociateAdminAccount")
DeleteAppsList = Action("DeleteAppsList")
DeleteNotificationChannel = Action("DeleteNotificationChannel")
DeletePolicy = Action("DeletePolicy")
DeleteProtocolsList = Action("DeleteProtocolsList")
DisassociateAdminAccount = Action("DisassociateAdminAccount")
GetAdminAccount = Action("GetAdminAccount")
GetAppsList = Action("GetAppsList")
GetComplianceDetail = Action("GetComplianceDetail")
GetNotificationChannel = Action("GetNotificationChannel")
GetPolicy = Action("GetPolicy")
GetProtectionStatus = Action("GetProtectionStatus")
GetProtocolsList = Action("GetProtocolsList")
GetViolationDetails = Action("GetViolationDetails")
ListAppsLists = Action("ListAppsLists")
ListComplianceStatus = Action("ListComplianceStatus")
ListMemberAccounts = Action("ListMemberAccounts")
ListPolicies = Action("ListPolicies")
ListProtocolsLists = Action("ListProtocolsLists")
ListTagsForResource = Action("ListTagsForResource")
PutAppsList = Action("PutAppsList")
PutNotificationChannel = Action("PutNotificationChannel")
PutPolicy = Action("PutPolicy")
PutProtocolsList = Action("PutProtocolsList")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaLive"
prefix = "medialive"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptInputDeviceTransfer = Action("AcceptInputDeviceTransfer")
BatchDelete = Action("BatchDelete")
BatchStart = Action("BatchStart")
BatchStop = Action("BatchStop")
BatchUpdateSchedule = Action("BatchUpdateSchedule")
CancelInputDeviceTransfer = Action("CancelInputDeviceTransfer")
CreateChannel = Action("CreateChannel")
CreateInput = Action("CreateInput")
CreateInputSecurityGroup = Action("CreateInputSecurityGroup")
CreateMultiplex = Action("CreateMultiplex")
CreateMultiplexProgram = Action("CreateMultiplexProgram")
CreatePartnerInput = Action("CreatePartnerInput")
CreateTags = Action("CreateTags")
DeleteChannel = Action("DeleteChannel")
DeleteInput = Action("DeleteInput")
DeleteInputSecurityGroup = Action("DeleteInputSecurityGroup")
DeleteMultiplex = Action("DeleteMultiplex")
DeleteMultiplexProgram = Action("DeleteMultiplexProgram")
DeleteReservation = Action("DeleteReservation")
DeleteSchedule = Action("DeleteSchedule")
DeleteTags = Action("DeleteTags")
DescribeChannel = Action("DescribeChannel")
DescribeInput = Action("DescribeInput")
DescribeInputDevice = Action("DescribeInputDevice")
DescribeInputDeviceThumbnail = Action("DescribeInputDeviceThumbnail")
DescribeInputSecurityGroup = Action("DescribeInputSecurityGroup")
DescribeMultiplex = Action("DescribeMultiplex")
DescribeMultiplexProgram = Action("DescribeMultiplexProgram")
DescribeOffering = Action("DescribeOffering")
DescribeReservation = Action("DescribeReservation")
DescribeSchedule = Action("DescribeSchedule")
ListChannels = Action("ListChannels")
ListInputDeviceTransfers = Action("ListInputDeviceTransfers")
ListInputDevices = Action("ListInputDevices")
ListInputSecurityGroups = Action("ListInputSecurityGroups")
ListInputs = Action("ListInputs")
ListMultiplexPrograms = Action("ListMultiplexPrograms")
ListMultiplexes = Action("ListMultiplexes")
ListOfferings = Action("ListOfferings")
ListReservations = Action("ListReservations")
ListTagsForResource = Action("ListTagsForResource")
PurchaseOffering = Action("PurchaseOffering")
RejectInputDeviceTransfer = Action("RejectInputDeviceTransfer")
StartChannel = Action("StartChannel")
StartMultiplex = Action("StartMultiplex")
StopChannel = Action("StopChannel")
StopMultiplex = Action("StopMultiplex")
TransferInputDevice = Action("TransferInputDevice")
UpdateChannel = Action("UpdateChannel")
UpdateChannelClass = Action("UpdateChannelClass")
UpdateInput = Action("UpdateInput")
UpdateInputDevice = Action("UpdateInputDevice")
UpdateInputSecurityGroup = Action("UpdateInputSecurityGroup")
UpdateMultiplex = Action("UpdateMultiplex")
UpdateMultiplexProgram = Action("UpdateMultiplexProgram")
UpdateReservation = Action("UpdateReservation")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Secrets Manager"
prefix = "secretsmanager"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelRotateSecret = Action("CancelRotateSecret")
CreateSecret = Action("CreateSecret")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSecret = Action("DeleteSecret")
DescribeSecret = Action("DescribeSecret")
GetRandomPassword = Action("GetRandomPassword")
GetResourcePolicy = Action("GetResourcePolicy")
GetSecretValue = Action("GetSecretValue")
ListSecretVersionIds = Action("ListSecretVersionIds")
ListSecrets = Action("ListSecrets")
PutResourcePolicy = Action("PutResourcePolicy")
PutSecretValue = Action("PutSecretValue")
RemoveRegionsFromReplication = Action("RemoveRegionsFromReplication")
ReplicateSecretToRegions = Action("ReplicateSecretToRegions")
RestoreSecret = Action("RestoreSecret")
RotateSecret = Action("RotateSecret")
StopReplicationToReplica = Action("StopReplicationToReplica")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateSecret = Action("UpdateSecret")
UpdateSecretVersionStage = Action("UpdateSecretVersionStage")
ValidateResourcePolicy = Action("ValidateResourcePolicy")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Kinesis Analytics"
prefix = "kinesisanalytics"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddApplicationCloudWatchLoggingOption = Action("AddApplicationCloudWatchLoggingOption")
AddApplicationInput = Action("AddApplicationInput")
AddApplicationInputProcessingConfiguration = Action(
    "AddApplicationInputProcessingConfiguration"
)
AddApplicationOutput = Action("AddApplicationOutput")
AddApplicationReferenceDataSource = Action("AddApplicationReferenceDataSource")
AddApplicationVpcConfiguration = Action("AddApplicationVpcConfiguration")
CreateApplication = Action("CreateApplication")
CreateApplicationPresignedUrl = Action("CreateApplicationPresignedUrl")
CreateApplicationSnapshot = Action("CreateApplicationSnapshot")
DeleteApplication = Action("DeleteApplication")
DeleteApplicationCloudWatchLoggingOption = Action(
    "DeleteApplicationCloudWatchLoggingOption"
)
DeleteApplicationInputProcessingConfiguration = Action(
    "DeleteApplicationInputProcessingConfiguration"
)
DeleteApplicationOutput = Action("DeleteApplicationOutput")
DeleteApplicationReferenceDataSource = Action("DeleteApplicationReferenceDataSource")
DeleteApplicationSnapshot = Action("DeleteApplicationSnapshot")
DeleteApplicationVpcConfiguration = Action("DeleteApplicationVpcConfiguration")
DescribeApplication = Action("DescribeApplication")
DescribeApplicationSnapshot = Action("DescribeApplicationSnapshot")
DescribeApplicationVersion = Action("DescribeApplicationVersion")
DiscoverInputSchema = Action("DiscoverInputSchema")
GetApplicationState = Action("GetApplicationState")
ListApplicationSnapshots = Action("ListApplicationSnapshots")
ListApplicationVersions = Action("ListApplicationVersions")
ListApplications = Action("ListApplications")
ListTagsForResource = Action("ListTagsForResource")
RollbackApplication = Action("RollbackApplication")
StartApplication = Action("StartApplication")
StopApplication = Action("StopApplication")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateApplicationMaintenanceConfiguration = Action(
    "UpdateApplicationMaintenanceConfiguration"
)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT SiteWise"
prefix = "iotsitewise"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateAssets = Action("AssociateAssets")
AssociateGatewaySink = Action("AssociateGatewaySink")
AssociateGatewaySource = Action("AssociateGatewaySource")
AssociateViewEntities = Action("AssociateViewEntities")
BatchAssociateProjectAssets = Action("BatchAssociateProjectAssets")
BatchDisassociateProjectAssets = Action("BatchDisassociateProjectAssets")
BatchPutAssetPropertyValue = Action("BatchPutAssetPropertyValue")
CreateAccessPolicy = Action("CreateAccessPolicy")
CreateAsset = Action("CreateAsset")
CreateAssetModel = Action("CreateAssetModel")
CreateAssetTemplate = Action("CreateAssetTemplate")
CreateDashboard = Action("CreateDashboard")
CreateGateway = Action("CreateGateway")
CreateGroup = Action("CreateGroup")
CreateMeasurementDataStore = Action("CreateMeasurementDataStore")
CreateMetricType = Action("CreateMetricType")
CreatePortal = Action("CreatePortal")
CreateProject = Action("CreateProject")
CreateView = Action("CreateView")
DeleteAccessPolicy = Action("DeleteAccessPolicy")
DeleteAsset = Action("DeleteAsset")
DeleteAssetModel = Action("DeleteAssetModel")
DeleteAssetTemplate = Action("DeleteAssetTemplate")
DeleteDashboard = Action("DeleteDashboard")
DeleteGateway = Action("DeleteGateway")
DeleteGroup = Action("DeleteGroup")
DeleteMeasurementDataStore = Action("DeleteMeasurementDataStore")
DeleteMetricType = Action("DeleteMetricType")
DeletePortal = Action("DeletePortal")
DeleteProject = Action("DeleteProject")
DeleteView = Action("DeleteView")
DeregisterViewEntities = Action("DeregisterViewEntities")
DescribeAccessPolicy = Action("DescribeAccessPolicy")
DescribeAsset = Action("DescribeAsset")
DescribeAssetModel = Action("DescribeAssetModel")
DescribeAssetProperty = Action("DescribeAssetProperty")
DescribeAssetTemplates = Action("DescribeAssetTemplates")
DescribeAssets = Action("DescribeAssets")
DescribeDashboard = Action("DescribeDashboard")
DescribeDefaultEncryptionConfiguration = Action(
    "DescribeDefaultEncryptionConfiguration"
)
DescribeGateway = Action("DescribeGateway")
DescribeGatewayCapabilityConfiguration = Action(
    "DescribeGatewayCapabilityConfiguration"
)
DescribeGateways = Action("DescribeGateways")
DescribeGroups = Action("DescribeGroups")
DescribeLoggingOptions = Action("DescribeLoggingOptions")
DescribeMeasurementDataStores = Action("DescribeMeasurementDataStores")
DescribeMetricTypes = Action("DescribeMetricTypes")
DescribePortal = Action("DescribePortal")
DescribeProject = Action("DescribeProject")
DescribeStorageConfiguration = Action("DescribeStorageConfiguration")
DescribeViews = Action("DescribeViews")
DisassociateAssets = Action("DisassociateAssets")
DisassociateGatewaySink = Action("DisassociateGatewaySink")
DisassociateGatewaySource = Action("DisassociateGatewaySource")
DisassociateViewEntities = Action("DisassociateViewEntities")
GetAssetPropertyAggregates = Action("GetAssetPropertyAggregates")
GetAssetPropertyValue = Action("GetAssetPropertyValue")
GetAssetPropertyValueHistory = Action("GetAssetPropertyValueHistory")
GetMeasurementData = Action("GetMeasurementData")
GetMetricData = Action("GetMetricData")
ListAccessPolicies = Action("ListAccessPolicies")
ListAssetModels = Action("ListAssetModels")
ListAssetRelationships = Action("ListAssetRelationships")
ListAssetTemplates = Action("ListAssetTemplates")
ListAssets = Action("ListAssets")
ListAssociatedAssets = Action("ListAssociatedAssets")
ListDashboards = Action("ListDashboards")
ListGateways = Action("ListGateways")
ListGroups = Action("ListGroups")
ListMeasurementDataStores = Action("ListMeasurementDataStores")
ListMeasurementDataStreams = Action("ListMeasurementDataStreams")
ListMetricTypes = Action("ListMetricTypes")
ListPortals = Action("ListPortals")
ListProjectAssets = Action("ListProjectAssets")
ListProjects = Action("ListProjects")
ListTagsForResource = Action("ListTagsForResource")
ListViewEntities = Action("ListViewEntities")
ListViews = Action("ListViews")
PutDefaultEncryptionConfiguration = Action("PutDefaultEncryptionConfiguration")
PutLoggingOptions = Action("PutLoggingOptions")
PutStorageConfiguration = Action("PutStorageConfiguration")
RegisterViewEntities = Action("RegisterViewEntities")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAccessPolicy = Action("UpdateAccessPolicy")
UpdateAsset = Action("UpdateAsset")
UpdateAssetModel = Action("UpdateAssetModel")
UpdateAssetModelPropertyRouting = Action("UpdateAssetModelPropertyRouting")
UpdateAssetProperty = Action("UpdateAssetProperty")
UpdateAssetTemplate = Action("UpdateAssetTemplate")
UpdateDashboard = Action("UpdateDashboard")
UpdateGateway = Action("UpdateGateway")
UpdateGatewayCapabilityConfiguration = Action("UpdateGatewayCapabilityConfiguration")
UpdateGroup = Action("UpdateGroup")
UpdateMeasurementDataStore = Action("UpdateMeasurementDataStore")
UpdatePortal = Action("UpdatePortal")
UpdateProject = Action("UpdateProject")
UpdateView = Action("UpdateView")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon MQ"
prefix = "mq"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateBroker = Action("CreateBroker")
CreateConfiguration = Action("CreateConfiguration")
CreateTags = Action("CreateTags")
CreateUser = Action("CreateUser")
DeleteBroker = Action("DeleteBroker")
DeleteTags = Action("DeleteTags")
DeleteUser = Action("DeleteUser")
DescribeBroker = Action("DescribeBroker")
DescribeBrokerEngineTypes = Action("DescribeBrokerEngineTypes")
DescribeBrokerInstanceOptions = Action("DescribeBrokerInstanceOptions")
DescribeConfiguration = Action("DescribeConfiguration")
DescribeConfigurationRevision = Action("DescribeConfigurationRevision")
DescribeUser = Action("DescribeUser")
ListBrokers = Action("ListBrokers")
ListConfigurationRevisions = Action("ListConfigurationRevisions")
ListConfigurations = Action("ListConfigurations")
ListTags = Action("ListTags")
ListUsers = Action("ListUsers")
RebootBroker = Action("RebootBroker")
UpdateBroker = Action("UpdateBroker")
UpdateConfiguration = Action("UpdateConfiguration")
UpdateUser = Action("UpdateUser")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CloudFormation"
prefix = "cloudformation"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivateType = Action("ActivateType")
BatchDescribeTypeConfigurations = Action("BatchDescribeTypeConfigurations")
CancelResourceRequest = Action("CancelResourceRequest")
CancelUpdateStack = Action("CancelUpdateStack")
ContinueUpdateRollback = Action("ContinueUpdateRollback")
CreateChangeSet = Action("CreateChangeSet")
CreateResource = Action("CreateResource")
CreateStack = Action("CreateStack")
CreateStackInstances = Action("CreateStackInstances")
CreateStackSet = Action("CreateStackSet")
CreateUploadBucket = Action("CreateUploadBucket")
DeactivateType = Action("DeactivateType")
DeleteChangeSet = Action("DeleteChangeSet")
DeleteResource = Action("DeleteResource")
DeleteStack = Action("DeleteStack")
DeleteStackInstances = Action("DeleteStackInstances")
DeleteStackSet = Action("DeleteStackSet")
DeregisterType = Action("DeregisterType")
DescribeAccountLimits = Action("DescribeAccountLimits")
DescribeChangeSet = Action("DescribeChangeSet")
DescribePublisher = Action("DescribePublisher")
DescribeStackDriftDetectionStatus = Action("DescribeStackDriftDetectionStatus")
DescribeStackEvents = Action("DescribeStackEvents")
DescribeStackInstance = Action("DescribeStackInstance")
DescribeStackResource = Action("DescribeStackResource")
DescribeStackResourceDrifts = Action("DescribeStackResourceDrifts")
DescribeStackResources = Action("DescribeStackResources")
DescribeStackSet = Action("DescribeStackSet")
DescribeStackSetOperation = Action("DescribeStackSetOperation")
DescribeStacks = Action("DescribeStacks")
DescribeType = Action("DescribeType")
DescribeTypeRegistration = Action("DescribeTypeRegistration")
DetectStackDrift = Action("DetectStackDrift")
DetectStackResourceDrift = Action("DetectStackResourceDrift")
DetectStackSetDrift = Action("DetectStackSetDrift")
EstimateTemplateCost = Action("EstimateTemplateCost")
ExecuteChangeSet = Action("ExecuteChangeSet")
GetResource = Action("GetResource")
GetResourceRequestStatus = Action("GetResourceRequestStatus")
GetStackPolicy = Action("GetStackPolicy")
GetTemplate = Action("GetTemplate")
GetTemplateSummary = Action("GetTemplateSummary")
ImportStacksToStackSet = Action("ImportStacksToStackSet")
ListChangeSets = Action("ListChangeSets")
ListExports = Action("ListExports")
ListImports = Action("ListImports")
ListResourceRequests = Action("ListResourceRequests")
ListResources = Action("ListResources")
ListStackInstances = Action("ListStackInstances")
ListStackResources = Action("ListStackResources")
ListStackSetOperationResults = Action("ListStackSetOperationResults")
ListStackSetOperations = Action("ListStackSetOperations")
ListStackSets = Action("ListStackSets")
ListStacks = Action("ListStacks")
ListTypeRegistrations = Action("ListTypeRegistrations")
ListTypeVersions = Action("ListTypeVersions")
ListTypes = Action("ListTypes")
PreviewStackUpdate = Action("PreviewStackUpdate")
PublishType = Action("PublishType")
RecordHandlerProgress = Action("RecordHandlerProgress")
RegisterPublisher = Action("RegisterPublisher")
RegisterType = Action("RegisterType")
SetStackPolicy = Action("SetStackPolicy")
SetTypeConfiguration = Action("SetTypeConfiguration")
SetTypeDefaultVersion = Action("SetTypeDefaultVersion")
SignalResource = Action("SignalResource")
StopStackSetOperation = Action("StopStackSetOperation")
TagResource = Action("TagResource")
TestType = Action("TestType")
UntagResource = Action("UntagResource")
UpdateResource = Action("UpdateResource")
UpdateStack = Action("UpdateStack")
UpdateStackInstances = Action("UpdateStackInstances")
UpdateStackSet = Action("UpdateStackSet")
UpdateTerminationProtection = Action("UpdateTerminationProtection")
ValidateTemplate = Action("ValidateTemplate")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaStore"
prefix = "mediastore"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateContainer = Action("CreateContainer")
DeleteContainer = Action("DeleteContainer")
DeleteContainerPolicy = Action("DeleteContainerPolicy")
DeleteCorsPolicy = Action("DeleteCorsPolicy")
DeleteLifecyclePolicy = Action("DeleteLifecyclePolicy")
DeleteMetricPolicy = Action("DeleteMetricPolicy")
DeleteObject = Action("DeleteObject")
DescribeContainer = Action("DescribeContainer")
DescribeObject = Action("DescribeObject")
GetContainerPolicy = Action("GetContainerPolicy")
GetCorsPolicy = Action("GetCorsPolicy")
GetLifecyclePolicy = Action("GetLifecyclePolicy")
GetMetricPolicy = Action("GetMetricPolicy")
GetObject = Action("GetObject")
ListContainers = Action("ListContainers")
ListItems = Action("ListItems")
ListTagsForResource = Action("ListTagsForResource")
PutContainerPolicy = Action("PutContainerPolicy")
PutCorsPolicy = Action("PutCorsPolicy")
PutLifecyclePolicy = Action("PutLifecyclePolicy")
PutMetricPolicy = Action("PutMetricPolicy")
PutObject = Action("PutObject")
StartAccessLogging = Action("StartAccessLogging")
StopAccessLogging = Action("StopAccessLogging")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Signer"
prefix = "signer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddProfilePermission = Action("AddProfilePermission")
CancelSigningProfile = Action("CancelSigningProfile")
DescribeSigningJob = Action("DescribeSigningJob")
GetSigningPlatform = Action("GetSigningPlatform")
GetSigningProfile = Action("GetSigningProfile")
ListProfilePermissions = Action("ListProfilePermissions")
ListSigningJobs = Action("ListSigningJobs")
ListSigningPlatforms = Action("ListSigningPlatforms")
ListSigningProfiles = Action("ListSigningProfiles")
ListTagsForResource = Action("ListTagsForResource")
PutSigningProfile = Action("PutSigningProfile")
RemoveProfilePermission = Action("RemoveProfilePermission")
RevokeSignature = Action("RevokeSignature")
RevokeSigningProfile = Action("RevokeSigningProfile")
StartSigningJob = Action("StartSigningJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Application Migration Service"
prefix = "mgn"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchCreateVolumeSnapshotGroupForMgn = Action("BatchCreateVolumeSnapshotGroupForMgn")
BatchDeleteSnapshotRequestForMgn = Action("BatchDeleteSnapshotRequestForMgn")
ChangeServerLifeCycleState = Action("ChangeServerLifeCycleState")
CreateReplicationConfigurationTemplate = Action(
    "CreateReplicationConfigurationTemplate"
)
DeleteJob = Action("DeleteJob")
DeleteReplicationConfigurationTemplate = Action(
    "DeleteReplicationConfigurationTemplate"
)
DeleteSourceServer = Action("DeleteSourceServer")
DescribeJobLogItems = Action("DescribeJobLogItems")
DescribeJobs = Action("DescribeJobs")
DescribeReplicationConfigurationTemplates = Action(
    "DescribeReplicationConfigurationTemplates"
)
DescribeReplicationServerAssociationsForMgn = Action(
    "DescribeReplicationServerAssociationsForMgn"
)
DescribeSnapshotRequestsForMgn = Action("DescribeSnapshotRequestsForMgn")
DescribeSourceServers = Action("DescribeSourceServers")
DisconnectFromService = Action("DisconnectFromService")
FinalizeCutover = Action("FinalizeCutover")
GetAgentCommandForMgn = Action("GetAgentCommandForMgn")
GetAgentConfirmedResumeInfoForMgn = Action("GetAgentConfirmedResumeInfoForMgn")
GetAgentInstallationAssetsForMgn = Action("GetAgentInstallationAssetsForMgn")
GetAgentReplicationInfoForMgn = Action("GetAgentReplicationInfoForMgn")
GetAgentRuntimeConfigurationForMgn = Action("GetAgentRuntimeConfigurationForMgn")
GetAgentSnapshotCreditsForMgn = Action("GetAgentSnapshotCreditsForMgn")
GetChannelCommandsForMgn = Action("GetChannelCommandsForMgn")
GetLaunchConfiguration = Action("GetLaunchConfiguration")
GetReplicationConfiguration = Action("GetReplicationConfiguration")
InitializeService = Action("InitializeService")
ListTagsForResource = Action("ListTagsForResource")
MarkAsArchived = Action("MarkAsArchived")
NotifyAgentAuthenticationForMgn = Action("NotifyAgentAuthenticationForMgn")
NotifyAgentConnectedForMgn = Action("NotifyAgentConnectedForMgn")
NotifyAgentDisconnectedForMgn = Action("NotifyAgentDisconnectedForMgn")
NotifyAgentReplicationProgressForMgn = Action("NotifyAgentReplicationProgressForMgn")
RegisterAgentForMgn = Action("RegisterAgentForMgn")
RetryDataReplication = Action("RetryDataReplication")
SendAgentLogsForMgn = Action("SendAgentLogsForMgn")
SendAgentMetricsForMgn = Action("SendAgentMetricsForMgn")
SendChannelCommandResultForMgn = Action("SendChannelCommandResultForMgn")
SendClientLogsForMgn = Action("SendClientLogsForMgn")
SendClientMetricsForMgn = Action("SendClientMetricsForMgn")
StartCutover = Action("StartCutover")
StartTest = Action("StartTest")
TagResource = Action("TagResource")
TerminateTargetInstances = Action("TerminateTargetInstances")
UntagResource = Action("UntagResource")
UpdateAgentBacklogForMgn = Action("UpdateAgentBacklogForMgn")
UpdateAgentConversionInfoForMgn = Action("UpdateAgentConversionInfoForMgn")
UpdateAgentReplicationInfoForMgn = Action("UpdateAgentReplicationInfoForMgn")
UpdateAgentReplicationProcessStateForMgn = Action(
    "UpdateAgentReplicationProcessStateForMgn"
)
UpdateAgentSourcePropertiesForMgn = Action("UpdateAgentSourcePropertiesForMgn")
UpdateLaunchConfiguration = Action("UpdateLaunchConfiguration")
UpdateReplicationConfiguration = Action("UpdateReplicationConfiguration")
UpdateReplicationConfigurationTemplate = Action(
    "UpdateReplicationConfigurationTemplate"
)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Lambda"
prefix = "lambda"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddLayerVersionPermission = Action("AddLayerVersionPermission")
AddPermission = Action("AddPermission")
CreateAlias = Action("CreateAlias")
CreateCodeSigningConfig = Action("CreateCodeSigningConfig")
CreateEventSourceMapping = Action("CreateEventSourceMapping")
CreateFunction = Action("CreateFunction")
DeleteAlias = Action("DeleteAlias")
DeleteCodeSigningConfig = Action("DeleteCodeSigningConfig")
DeleteEventSourceMapping = Action("DeleteEventSourceMapping")
DeleteFunction = Action("DeleteFunction")
DeleteFunctionCodeSigningConfig = Action("DeleteFunctionCodeSigningConfig")
DeleteFunctionConcurrency = Action("DeleteFunctionConcurrency")
DeleteFunctionEventInvokeConfig = Action("DeleteFunctionEventInvokeConfig")
DeleteLayerVersion = Action("DeleteLayerVersion")
DeleteProvisionedConcurrencyConfig = Action("DeleteProvisionedConcurrencyConfig")
DisableReplication = Action("DisableReplication")
EnableReplication = Action("EnableReplication")
GetAccountSettings = Action("GetAccountSettings")
GetAlias = Action("GetAlias")
GetCodeSigningConfig = Action("GetCodeSigningConfig")
GetEventSourceMapping = Action("GetEventSourceMapping")
GetFunction = Action("GetFunction")
GetFunctionCodeSigningConfig = Action("GetFunctionCodeSigningConfig")
GetFunctionConcurrency = Action("GetFunctionConcurrency")
GetFunctionConfiguration = Action("GetFunctionConfiguration")
GetFunctionEventInvokeConfig = Action("GetFunctionEventInvokeConfig")
GetLayerVersion = Action("GetLayerVersion")
GetLayerVersionByArn = Action("GetLayerVersionByArn")
GetLayerVersionPolicy = Action("GetLayerVersionPolicy")
GetPolicy = Action("GetPolicy")
GetProvisionedConcurrencyConfig = Action("GetProvisionedConcurrencyConfig")
InvokeAsync = Action("InvokeAsync")
InvokeFunction = Action("InvokeFunction")
ListAliases = Action("ListAliases")
ListCodeSigningConfigs = Action("ListCodeSigningConfigs")
ListEventSourceMappings = Action("ListEventSourceMappings")
ListFunctionEventInvokeConfigs = Action("ListFunctionEventInvokeConfigs")
ListFunctions = Action("ListFunctions")
ListFunctionsByCodeSigningConfig = Action("ListFunctionsByCodeSigningConfig")
ListLayerVersions = Action("ListLayerVersions")
ListLayers = Action("ListLayers")
ListProvisionedConcurrencyConfigs = Action("ListProvisionedConcurrencyConfigs")
ListTags = Action("ListTags")
ListVersionsByFunction = Action("ListVersionsByFunction")
PublishLayerVersion = Action("PublishLayerVersion")
PublishVersion = Action("PublishVersion")
PutFunctionCodeSigningConfig = Action("PutFunctionCodeSigningConfig")
PutFunctionConcurrency = Action("PutFunctionConcurrency")
PutFunctionEventInvokeConfig = Action("PutFunctionEventInvokeConfig")
PutProvisionedConcurrencyConfig = Action("PutProvisionedConcurrencyConfig")
RemoveLayerVersionPermission = Action("RemoveLayerVersionPermission")
RemovePermission = Action("RemovePermission")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAlias = Action("UpdateAlias")
UpdateCodeSigningConfig = Action("UpdateCodeSigningConfig")
UpdateEventSourceMapping = Action("UpdateEventSourceMapping")
UpdateFunctionCode = Action("UpdateFunctionCode")
UpdateFunctionCodeSigningConfig = Action("UpdateFunctionCodeSigningConfig")
UpdateFunctionConfiguration = Action("UpdateFunctionConfiguration")
UpdateFunctionEventInvokeConfig = Action("UpdateFunctionEventInvokeConfig")



import awacs.sns as sns
import awacs.sqs as sqs
from awacs.aws import Allow, ArnEquals, AWSPrincipal, Condition, Policy, Statement

region = "us-east-1"
account = "012345678891"

pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Principal=AWSPrincipal("210987654321"),
            Action=[sqs.SendMessage],
            Resource=[
                sqs.ARN(region, account, "your_queue_xyz"),
            ],
            Condition=Condition(
                ArnEquals(
                    "aws:SourceArn",
                    sns.ARN(region, "123456789012", "your_special_topic_1"),
                ),
            ),
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Systems Manager Incident Manager Contacts"
prefix = "ssm-contacts"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptPage = Action("AcceptPage")
ActivateContactChannel = Action("ActivateContactChannel")
AssociateContact = Action("AssociateContact")
CreateContact = Action("CreateContact")
CreateContactChannel = Action("CreateContactChannel")
DeactivateContactChannel = Action("DeactivateContactChannel")
DeleteContact = Action("DeleteContact")
DeleteContactChannel = Action("DeleteContactChannel")
DeleteContactPolicy = Action("DeleteContactPolicy")
DescribeEngagement = Action("DescribeEngagement")
DescribePage = Action("DescribePage")
GetContact = Action("GetContact")
GetContactChannel = Action("GetContactChannel")
GetContactPolicy = Action("GetContactPolicy")
ListContactChannels = Action("ListContactChannels")
ListContacts = Action("ListContacts")
ListEngagements = Action("ListEngagements")
ListPageReceipts = Action("ListPageReceipts")
ListPagesByContact = Action("ListPagesByContact")
ListPagesByEngagement = Action("ListPagesByEngagement")
ListTagsForResource = Action("ListTagsForResource")
PutContactPolicy = Action("PutContactPolicy")
SendActivationCode = Action("SendActivationCode")
StartEngagement = Action("StartEngagement")
StopEngagement = Action("StopEngagement")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateContact = Action("UpdateContact")
UpdateContactChannel = Action("UpdateContactChannel")
UpdateContactPolicy = Action("UpdateContactPolicy")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon S3 on Outposts"
prefix = "s3-outposts"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AbortMultipartUpload = Action("AbortMultipartUpload")
CreateAccessPoint = Action("CreateAccessPoint")
CreateBucket = Action("CreateBucket")
CreateEndpoint = Action("CreateEndpoint")
DeleteAccessPoint = Action("DeleteAccessPoint")
DeleteAccessPointPolicy = Action("DeleteAccessPointPolicy")
DeleteBucket = Action("DeleteBucket")
DeleteBucketPolicy = Action("DeleteBucketPolicy")
DeleteEndpoint = Action("DeleteEndpoint")
DeleteObject = Action("DeleteObject")
DeleteObjectTagging = Action("DeleteObjectTagging")
GetAccessPoint = Action("GetAccessPoint")
GetAccessPointPolicy = Action("GetAccessPointPolicy")
GetBucket = Action("GetBucket")
GetBucketPolicy = Action("GetBucketPolicy")
GetBucketTagging = Action("GetBucketTagging")
GetLifecycleConfiguration = Action("GetLifecycleConfiguration")
GetObject = Action("GetObject")
GetObjectTagging = Action("GetObjectTagging")
ListAccessPoints = Action("ListAccessPoints")
ListBucket = Action("ListBucket")
ListBucketMultipartUploads = Action("ListBucketMultipartUploads")
ListEndpoints = Action("ListEndpoints")
ListMultipartUploadParts = Action("ListMultipartUploadParts")
ListRegionalBuckets = Action("ListRegionalBuckets")
PutAccessPointPolicy = Action("PutAccessPointPolicy")
PutBucketPolicy = Action("PutBucketPolicy")
PutBucketTagging = Action("PutBucketTagging")
PutLifecycleConfiguration = Action("PutLifecycleConfiguration")
PutObject = Action("PutObject")
PutObjectAcl = Action("PutObjectAcl")
PutObjectTagging = Action("PutObjectTagging")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon FinSpace"
prefix = "finspace"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateEnvironment = Action("CreateEnvironment")
CreateUser = Action("CreateUser")
DeleteEnvironment = Action("DeleteEnvironment")
DeleteUser = Action("DeleteUser")
GetEnvironment = Action("GetEnvironment")
GetLoadSampleDataSetGroupIntoEnvironmentStatus = Action(
    "GetLoadSampleDataSetGroupIntoEnvironmentStatus"
)
GetUser = Action("GetUser")
ListEnvironments = Action("ListEnvironments")
ListTagsForResource = Action("ListTagsForResource")
ListUsers = Action("ListUsers")
LoadSampleDataSetGroupIntoEnvironment = Action("LoadSampleDataSetGroupIntoEnvironment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateEnvironment = Action("UpdateEnvironment")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Lookout for Equipment"
prefix = "lookoutequipment"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDataset = Action("CreateDataset")
CreateInferenceScheduler = Action("CreateInferenceScheduler")
CreateModel = Action("CreateModel")
DeleteDataset = Action("DeleteDataset")
DeleteInferenceScheduler = Action("DeleteInferenceScheduler")
DeleteModel = Action("DeleteModel")
DescribeDataIngestionJob = Action("DescribeDataIngestionJob")
DescribeDataset = Action("DescribeDataset")
DescribeInferenceScheduler = Action("DescribeInferenceScheduler")
DescribeModel = Action("DescribeModel")
ListDataIngestionJobs = Action("ListDataIngestionJobs")
ListDatasets = Action("ListDatasets")
ListInferenceExecutions = Action("ListInferenceExecutions")
ListInferenceSchedulers = Action("ListInferenceSchedulers")
ListModels = Action("ListModels")
ListTagsForResource = Action("ListTagsForResource")
StartDataIngestionJob = Action("StartDataIngestionJob")
StartInferenceScheduler = Action("StartInferenceScheduler")
StopInferenceScheduler = Action("StopInferenceScheduler")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateInferenceScheduler = Action("UpdateInferenceScheduler")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon AppIntegrations"
prefix = "app-integrations"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDataIntegration = Action("CreateDataIntegration")
CreateDataIntegrationAssociation = Action("CreateDataIntegrationAssociation")
CreateEventIntegration = Action("CreateEventIntegration")
CreateEventIntegrationAssociation = Action("CreateEventIntegrationAssociation")
DeleteDataIntegration = Action("DeleteDataIntegration")
DeleteDataIntegrationAssociation = Action("DeleteDataIntegrationAssociation")
DeleteEventIntegration = Action("DeleteEventIntegration")
DeleteEventIntegrationAssociation = Action("DeleteEventIntegrationAssociation")
GetDataIntegration = Action("GetDataIntegration")
GetEventIntegration = Action("GetEventIntegration")
ListDataIntegrationAssociations = Action("ListDataIntegrationAssociations")
ListDataIntegrations = Action("ListDataIntegrations")
ListEventIntegrationAssociations = Action("ListEventIntegrationAssociations")
ListEventIntegrations = Action("ListEventIntegrations")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDataIntegration = Action("UpdateDataIntegration")
UpdateEventIntegration = Action("UpdateEventIntegration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS App Runner"
prefix = "apprunner"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateCustomDomain = Action("AssociateCustomDomain")
CreateAutoScalingConfiguration = Action("CreateAutoScalingConfiguration")
CreateConnection = Action("CreateConnection")
CreateService = Action("CreateService")
DeleteAutoScalingConfiguration = Action("DeleteAutoScalingConfiguration")
DeleteConnection = Action("DeleteConnection")
DeleteService = Action("DeleteService")
DescribeAutoScalingConfiguration = Action("DescribeAutoScalingConfiguration")
DescribeCustomDomains = Action("DescribeCustomDomains")
DescribeOperation = Action("DescribeOperation")
DescribeService = Action("DescribeService")
DisassociateCustomDomain = Action("DisassociateCustomDomain")
ListAutoScalingConfigurations = Action("ListAutoScalingConfigurations")
ListConnections = Action("ListConnections")
ListOperations = Action("ListOperations")
ListServices = Action("ListServices")
ListTagsForResource = Action("ListTagsForResource")
PauseService = Action("PauseService")
ResumeService = Action("ResumeService")
StartDeployment = Action("StartDeployment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateService = Action("UpdateService")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Certificate Manager"
prefix = "acm"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToCertificate = Action("AddTagsToCertificate")
DeleteCertificate = Action("DeleteCertificate")
DescribeCertificate = Action("DescribeCertificate")
ExportCertificate = Action("ExportCertificate")
GetAccountConfiguration = Action("GetAccountConfiguration")
GetCertificate = Action("GetCertificate")
ImportCertificate = Action("ImportCertificate")
ListCertificates = Action("ListCertificates")
ListTagsForCertificate = Action("ListTagsForCertificate")
PutAccountConfiguration = Action("PutAccountConfiguration")
RemoveTagsFromCertificate = Action("RemoveTagsFromCertificate")
RenewCertificate = Action("RenewCertificate")
RequestCertificate = Action("RequestCertificate")
ResendValidationEmail = Action("ResendValidationEmail")
UpdateCertificateOptions = Action("UpdateCertificateOptions")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon HealthLake"
prefix = "healthlake"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateFHIRDatastore = Action("CreateFHIRDatastore")
CreateResource = Action("CreateResource")
DeleteFHIRDatastore = Action("DeleteFHIRDatastore")
DeleteResource = Action("DeleteResource")
DescribeFHIRDatastore = Action("DescribeFHIRDatastore")
DescribeFHIRExportJob = Action("DescribeFHIRExportJob")
DescribeFHIRImportJob = Action("DescribeFHIRImportJob")
GetCapabilities = Action("GetCapabilities")
ListFHIRDatastores = Action("ListFHIRDatastores")
ListFHIRExportJobs = Action("ListFHIRExportJobs")
ListFHIRImportJobs = Action("ListFHIRImportJobs")
ListTagsForResource = Action("ListTagsForResource")
ReadResource = Action("ReadResource")
SearchWithGet = Action("SearchWithGet")
SearchWithPost = Action("SearchWithPost")
StartFHIRExportJob = Action("StartFHIRExportJob")
StartFHIRImportJob = Action("StartFHIRImportJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateResource = Action("UpdateResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeBuild"
prefix = "codebuild"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchDeleteBuilds = Action("BatchDeleteBuilds")
BatchGetBuildBatches = Action("BatchGetBuildBatches")
BatchGetBuilds = Action("BatchGetBuilds")
BatchGetProjects = Action("BatchGetProjects")
BatchGetReportGroups = Action("BatchGetReportGroups")
BatchGetReports = Action("BatchGetReports")
BatchPutCodeCoverages = Action("BatchPutCodeCoverages")
BatchPutTestCases = Action("BatchPutTestCases")
CreateProject = Action("CreateProject")
CreateReport = Action("CreateReport")
CreateReportGroup = Action("CreateReportGroup")
CreateWebhook = Action("CreateWebhook")
DeleteBuildBatch = Action("DeleteBuildBatch")
DeleteOAuthToken = Action("DeleteOAuthToken")
DeleteProject = Action("DeleteProject")
DeleteReport = Action("DeleteReport")
DeleteReportGroup = Action("DeleteReportGroup")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSourceCredentials = Action("DeleteSourceCredentials")
DeleteWebhook = Action("DeleteWebhook")
DescribeCodeCoverages = Action("DescribeCodeCoverages")
DescribeTestCases = Action("DescribeTestCases")
GetReportGroupTrend = Action("GetReportGroupTrend")
GetResourcePolicy = Action("GetResourcePolicy")
ImportSourceCredentials = Action("ImportSourceCredentials")
InvalidateProjectCache = Action("InvalidateProjectCache")
ListBuildBatches = Action("ListBuildBatches")
ListBuildBatchesForProject = Action("ListBuildBatchesForProject")
ListBuilds = Action("ListBuilds")
ListBuildsForProject = Action("ListBuildsForProject")
ListConnectedOAuthAccounts = Action("ListConnectedOAuthAccounts")
ListCuratedEnvironmentImages = Action("ListCuratedEnvironmentImages")
ListProjects = Action("ListProjects")
ListReportGroups = Action("ListReportGroups")
ListReports = Action("ListReports")
ListReportsForReportGroup = Action("ListReportsForReportGroup")
ListRepositories = Action("ListRepositories")
ListSharedProjects = Action("ListSharedProjects")
ListSharedReportGroups = Action("ListSharedReportGroups")
ListSourceCredentials = Action("ListSourceCredentials")
PersistOAuthToken = Action("PersistOAuthToken")
PutResourcePolicy = Action("PutResourcePolicy")
RetryBuild = Action("RetryBuild")
RetryBuildBatch = Action("RetryBuildBatch")
StartBuild = Action("StartBuild")
StartBuildBatch = Action("StartBuildBatch")
StopBuild = Action("StopBuild")
StopBuildBatch = Action("StopBuildBatch")
UpdateProject = Action("UpdateProject")
UpdateProjectVisibility = Action("UpdateProjectVisibility")
UpdateReport = Action("UpdateReport")
UpdateReportGroup = Action("UpdateReportGroup")
UpdateWebhook = Action("UpdateWebhook")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaPackage VOD"
prefix = "mediapackage-vod"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ConfigureLogs = Action("ConfigureLogs")
CreateAsset = Action("CreateAsset")
CreatePackagingConfiguration = Action("CreatePackagingConfiguration")
CreatePackagingGroup = Action("CreatePackagingGroup")
DeleteAsset = Action("DeleteAsset")
DeletePackagingConfiguration = Action("DeletePackagingConfiguration")
DeletePackagingGroup = Action("DeletePackagingGroup")
DescribeAsset = Action("DescribeAsset")
DescribePackagingConfiguration = Action("DescribePackagingConfiguration")
DescribePackagingGroup = Action("DescribePackagingGroup")
ListAssets = Action("ListAssets")
ListPackagingConfigurations = Action("ListPackagingConfigurations")
ListPackagingGroups = Action("ListPackagingGroups")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdatePackagingGroup = Action("UpdatePackagingGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Detective"
prefix = "detective"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptInvitation = Action("AcceptInvitation")
CreateGraph = Action("CreateGraph")
CreateMembers = Action("CreateMembers")
DeleteGraph = Action("DeleteGraph")
DeleteMembers = Action("DeleteMembers")
DisassociateMembership = Action("DisassociateMembership")
GetFreeTrialEligibility = Action("GetFreeTrialEligibility")
GetGraphIngestState = Action("GetGraphIngestState")
GetMembers = Action("GetMembers")
GetPricingInformation = Action("GetPricingInformation")
GetUsageInformation = Action("GetUsageInformation")
ListGraphs = Action("ListGraphs")
ListInvitations = Action("ListInvitations")
ListMembers = Action("ListMembers")
ListTagsForResource = Action("ListTagsForResource")
RejectInvitation = Action("RejectInvitation")
SearchGraph = Action("SearchGraph")
StartMonitoringMember = Action("StartMonitoringMember")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CloudTrail"
prefix = "cloudtrail"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTags = Action("AddTags")
CreateTrail = Action("CreateTrail")
DeleteTrail = Action("DeleteTrail")
DescribeTrails = Action("DescribeTrails")
GetEventSelectors = Action("GetEventSelectors")
GetInsightSelectors = Action("GetInsightSelectors")
GetTrail = Action("GetTrail")
GetTrailStatus = Action("GetTrailStatus")
ListPublicKeys = Action("ListPublicKeys")
ListTags = Action("ListTags")
ListTrails = Action("ListTrails")
LookupEvents = Action("LookupEvents")
PutEventSelectors = Action("PutEventSelectors")
PutInsightSelectors = Action("PutInsightSelectors")
RemoveTags = Action("RemoveTags")
StartLogging = Action("StartLogging")
StopLogging = Action("StopLogging")
UpdateTrail = Action("UpdateTrail")



# Example taken from AWS docs:
# http://docs.aws.amazon.com/IAM/latest/UserGuide/
# ExampleIAMPolicies.html#iampolicy-example-s3homedir

import awacs.s3 as s3
from awacs.aws import (
    Action,
    Allow,
    Condition,
    Policy,
    Statement,
    StringEquals,
    StringLike,
)

pd = Policy(
    Statement=[
        Statement(
            Action=[s3.ListAllMyBuckets, s3.GetBucketLocation],
            Effect=Allow,
            Resource=[
                s3.ARN("*"),
            ],
        ),
        Statement(
            Action=[s3.ListBucket],
            Effect=Allow,
            Resource=[s3.ARN("myBucket")],
            Condition=Condition(
                StringEquals(
                    {
                        "s3:prefix": ["", "home/"],
                        "s3:delimiter": ["/"],
                    }
                ),
            ),
        ),
        Statement(
            Action=[s3.ListBucket],
            Effect=Allow,
            Resource=[s3.ARN("myBucket")],
            Condition=Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
        ),
        Statement(
            Action=[Action("s3", "*")],
            Effect=Allow,
            Resource=[
                s3.ARN("myBucket/home/${aws:username}"),
                s3.ARN("myBucket/home/${aws:username}/*"),
            ],
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Server Migration Service"
prefix = "sms"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApp = Action("CreateApp")
CreateReplicationJob = Action("CreateReplicationJob")
DeleteApp = Action("DeleteApp")
DeleteAppLaunchConfiguration = Action("DeleteAppLaunchConfiguration")
DeleteAppReplicationConfiguration = Action("DeleteAppReplicationConfiguration")
DeleteAppValidationConfiguration = Action("DeleteAppValidationConfiguration")
DeleteReplicationJob = Action("DeleteReplicationJob")
DeleteServerCatalog = Action("DeleteServerCatalog")
DisassociateConnector = Action("DisassociateConnector")
DisassociateConnectors = Action("DisassociateConnectors")
GenerateChangeSet = Action("GenerateChangeSet")
GenerateTemplate = Action("GenerateTemplate")
GetApp = Action("GetApp")
GetAppLaunchConfiguration = Action("GetAppLaunchConfiguration")
GetAppReplicationConfiguration = Action("GetAppReplicationConfiguration")
GetAppValidationConfiguration = Action("GetAppValidationConfiguration")
GetAppValidationOutput = Action("GetAppValidationOutput")
GetConnectors = Action("GetConnectors")
GetMessages = Action("GetMessages")
GetReplicationJobs = Action("GetReplicationJobs")
GetReplicationRuns = Action("GetReplicationRuns")
GetServers = Action("GetServers")
ImportAppCatalog = Action("ImportAppCatalog")
ImportServerCatalog = Action("ImportServerCatalog")
LaunchApp = Action("LaunchApp")
ListApps = Action("ListApps")
NotifyAppValidationOutput = Action("NotifyAppValidationOutput")
PutAppLaunchConfiguration = Action("PutAppLaunchConfiguration")
PutAppReplicationConfiguration = Action("PutAppReplicationConfiguration")
PutAppValidationConfiguration = Action("PutAppValidationConfiguration")
SendMessage = Action("SendMessage")
StartAppReplication = Action("StartAppReplication")
StartOnDemandAppReplication = Action("StartOnDemandAppReplication")
StartOnDemandReplicationRun = Action("StartOnDemandReplicationRun")
StopAppReplication = Action("StopAppReplication")
TerminateApp = Action("TerminateApp")
UpdateApp = Action("UpdateApp")
UpdateReplicationJob = Action("UpdateReplicationJob")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon OpenSearch Service (successor to Amazon Elasticsearch Service)"
prefix = "es"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptInboundConnection = Action("AcceptInboundConnection")
AcceptInboundCrossClusterSearchConnection = Action(
    "AcceptInboundCrossClusterSearchConnection"
)
AddTags = Action("AddTags")
AssociatePackage = Action("AssociatePackage")
CancelElasticsearchServiceSoftwareUpdate = Action(
    "CancelElasticsearchServiceSoftwareUpdate"
)
CancelServiceSoftwareUpdate = Action("CancelServiceSoftwareUpdate")
CreateDataPrepperPipeline = Action("CreateDataPrepperPipeline")
CreateDomain = Action("CreateDomain")
CreateElasticsearchDomain = Action("CreateElasticsearchDomain")
CreateElasticsearchServiceRole = Action("CreateElasticsearchServiceRole")
CreateOutboundConnection = Action("CreateOutboundConnection")
CreateOutboundCrossClusterSearchConnection = Action(
    "CreateOutboundCrossClusterSearchConnection"
)
CreatePackage = Action("CreatePackage")
CreateServiceRole = Action("CreateServiceRole")
DeleteDataPrepperPipeline = Action("DeleteDataPrepperPipeline")
DeleteDomain = Action("DeleteDomain")
DeleteElasticsearchDomain = Action("DeleteElasticsearchDomain")
DeleteElasticsearchServiceRole = Action("DeleteElasticsearchServiceRole")
DeleteInboundConnection = Action("DeleteInboundConnection")
DeleteInboundCrossClusterSearchConnection = Action(
    "DeleteInboundCrossClusterSearchConnection"
)
DeleteOutboundConnection = Action("DeleteOutboundConnection")
DeleteOutboundCrossClusterSearchConnection = Action(
    "DeleteOutboundCrossClusterSearchConnection"
)
DeletePackage = Action("DeletePackage")
DescribeDataPrepperPipeline = Action("DescribeDataPrepperPipeline")
DescribeDomain = Action("DescribeDomain")
DescribeDomainAutoTunes = Action("DescribeDomainAutoTunes")
DescribeDomainConfig = Action("DescribeDomainConfig")
DescribeDomains = Action("DescribeDomains")
DescribeElasticsearchDomain = Action("DescribeElasticsearchDomain")
DescribeElasticsearchDomainConfig = Action("DescribeElasticsearchDomainConfig")
DescribeElasticsearchDomains = Action("DescribeElasticsearchDomains")
DescribeElasticsearchInstanceTypeLimits = Action(
    "DescribeElasticsearchInstanceTypeLimits"
)
DescribeInboundConnections = Action("DescribeInboundConnections")
DescribeInboundCrossClusterSearchConnections = Action(
    "DescribeInboundCrossClusterSearchConnections"
)
DescribeInstanceTypeLimits = Action("DescribeInstanceTypeLimits")
DescribeOutboundConnections = Action("DescribeOutboundConnections")
DescribeOutboundCrossClusterSearchConnections = Action(
    "DescribeOutboundCrossClusterSearchConnections"
)
DescribePackages = Action("DescribePackages")
DescribeReservedElasticsearchInstanceOfferings = Action(
    "DescribeReservedElasticsearchInstanceOfferings"
)
DescribeReservedElasticsearchInstances = Action(
    "DescribeReservedElasticsearchInstances"
)
DescribeReservedInstanceOfferings = Action("DescribeReservedInstanceOfferings")
DescribeReservedInstances = Action("DescribeReservedInstances")
DissociatePackage = Action("DissociatePackage")
ESCrossClusterGet = Action("ESCrossClusterGet")
ESHttpDelete = Action("ESHttpDelete")
ESHttpGet = Action("ESHttpGet")
ESHttpHead = Action("ESHttpHead")
ESHttpPatch = Action("ESHttpPatch")
ESHttpPost = Action("ESHttpPost")
ESHttpPut = Action("ESHttpPut")
GetCompatibleElasticsearchVersions = Action("GetCompatibleElasticsearchVersions")
GetCompatibleVersions = Action("GetCompatibleVersions")
GetPackageVersionHistory = Action("GetPackageVersionHistory")
GetUpgradeHistory = Action("GetUpgradeHistory")
GetUpgradeStatus = Action("GetUpgradeStatus")
IngestDataPrepperPipeline = Action("IngestDataPrepperPipeline")
ListDataPrepperPipelines = Action("ListDataPrepperPipelines")
ListDomainNames = Action("ListDomainNames")
ListDomainsForPackage = Action("ListDomainsForPackage")
ListElasticsearchInstanceTypeDetails = Action("ListElasticsearchInstanceTypeDetails")
ListElasticsearchInstanceTypes = Action("ListElasticsearchInstanceTypes")
ListElasticsearchVersions = Action("ListElasticsearchVersions")
ListInstanceTypeDetails = Action("ListInstanceTypeDetails")
ListInstanceTypes = Action("ListInstanceTypes")
ListPackagesForDomain = Action("ListPackagesForDomain")
ListTags = Action("ListTags")
ListVersions = Action("ListVersions")
PurchaseReservedElasticsearchInstance = Action("PurchaseReservedElasticsearchInstance")
PurchaseReservedElasticsearchInstanceOffering = Action(
    "PurchaseReservedElasticsearchInstanceOffering"
)
PurchaseReservedInstanceOffering = Action("PurchaseReservedInstanceOffering")
RejectInboundConnection = Action("RejectInboundConnection")
RejectInboundCrossClusterSearchConnection = Action(
    "RejectInboundCrossClusterSearchConnection"
)
RemoveTags = Action("RemoveTags")
StartElasticsearchServiceSoftwareUpdate = Action(
    "StartElasticsearchServiceSoftwareUpdate"
)
StartServiceSoftwareUpdate = Action("StartServiceSoftwareUpdate")
UpdateDataPrepperPipeline = Action("UpdateDataPrepperPipeline")
UpdateDomainConfig = Action("UpdateDomainConfig")
UpdateElasticsearchDomainConfig = Action("UpdateElasticsearchDomainConfig")
UpdatePackage = Action("UpdatePackage")
UpgradeDomain = Action("UpgradeDomain")
UpgradeElasticsearchDomain = Action("UpgradeElasticsearchDomain")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon DynamoDB"
prefix = "dynamodb"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGetItem = Action("BatchGetItem")
BatchWriteItem = Action("BatchWriteItem")
ConditionCheckItem = Action("ConditionCheckItem")
CreateBackup = Action("CreateBackup")
CreateGlobalTable = Action("CreateGlobalTable")
CreateTable = Action("CreateTable")
CreateTableReplica = Action("CreateTableReplica")
DeleteBackup = Action("DeleteBackup")
DeleteItem = Action("DeleteItem")
DeleteTable = Action("DeleteTable")
DeleteTableReplica = Action("DeleteTableReplica")
DescribeBackup = Action("DescribeBackup")
DescribeContinuousBackups = Action("DescribeContinuousBackups")
DescribeContributorInsights = Action("DescribeContributorInsights")
DescribeExport = Action("DescribeExport")
DescribeGlobalTable = Action("DescribeGlobalTable")
DescribeGlobalTableSettings = Action("DescribeGlobalTableSettings")
DescribeKinesisStreamingDestination = Action("DescribeKinesisStreamingDestination")
DescribeLimits = Action("DescribeLimits")
DescribeReservedCapacity = Action("DescribeReservedCapacity")
DescribeReservedCapacityOfferings = Action("DescribeReservedCapacityOfferings")
DescribeStream = Action("DescribeStream")
DescribeTable = Action("DescribeTable")
DescribeTableReplicaAutoScaling = Action("DescribeTableReplicaAutoScaling")
DescribeTimeToLive = Action("DescribeTimeToLive")
DisableKinesisStreamingDestination = Action("DisableKinesisStreamingDestination")
EnableKinesisStreamingDestination = Action("EnableKinesisStreamingDestination")
ExportTableToPointInTime = Action("ExportTableToPointInTime")
GetItem = Action("GetItem")
GetRecords = Action("GetRecords")
GetShardIterator = Action("GetShardIterator")
ListBackups = Action("ListBackups")
ListContributorInsights = Action("ListContributorInsights")
ListExports = Action("ListExports")
ListGlobalTables = Action("ListGlobalTables")
ListStreams = Action("ListStreams")
ListTables = Action("ListTables")
ListTagsOfResource = Action("ListTagsOfResource")
PartiQLDelete = Action("PartiQLDelete")
PartiQLInsert = Action("PartiQLInsert")
PartiQLSelect = Action("PartiQLSelect")
PartiQLUpdate = Action("PartiQLUpdate")
PurchaseReservedCapacityOfferings = Action("PurchaseReservedCapacityOfferings")
PutItem = Action("PutItem")
Query = Action("Query")
RestoreTableFromBackup = Action("RestoreTableFromBackup")
RestoreTableToPointInTime = Action("RestoreTableToPointInTime")
Scan = Action("Scan")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateContinuousBackups = Action("UpdateContinuousBackups")
UpdateContributorInsights = Action("UpdateContributorInsights")
UpdateGlobalTable = Action("UpdateGlobalTable")
UpdateGlobalTableSettings = Action("UpdateGlobalTableSettings")
UpdateItem = Action("UpdateItem")
UpdateTable = Action("UpdateTable")
UpdateTableReplicaAutoScaling = Action("UpdateTableReplicaAutoScaling")
UpdateTimeToLive = Action("UpdateTimeToLive")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Config"
prefix = "config"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGetAggregateResourceConfig = Action("BatchGetAggregateResourceConfig")
BatchGetResourceConfig = Action("BatchGetResourceConfig")
DeleteAggregationAuthorization = Action("DeleteAggregationAuthorization")
DeleteConfigRule = Action("DeleteConfigRule")
DeleteConfigurationAggregator = Action("DeleteConfigurationAggregator")
DeleteConfigurationRecorder = Action("DeleteConfigurationRecorder")
DeleteConformancePack = Action("DeleteConformancePack")
DeleteDeliveryChannel = Action("DeleteDeliveryChannel")
DeleteEvaluationResults = Action("DeleteEvaluationResults")
DeleteOrganizationConfigRule = Action("DeleteOrganizationConfigRule")
DeleteOrganizationConformancePack = Action("DeleteOrganizationConformancePack")
DeletePendingAggregationRequest = Action("DeletePendingAggregationRequest")
DeleteRemediationConfiguration = Action("DeleteRemediationConfiguration")
DeleteRemediationExceptions = Action("DeleteRemediationExceptions")
DeleteResourceConfig = Action("DeleteResourceConfig")
DeleteRetentionConfiguration = Action("DeleteRetentionConfiguration")
DeleteStoredQuery = Action("DeleteStoredQuery")
DeliverConfigSnapshot = Action("DeliverConfigSnapshot")
DescribeAggregateComplianceByConfigRules = Action(
    "DescribeAggregateComplianceByConfigRules"
)
DescribeAggregateComplianceByConformancePacks = Action(
    "DescribeAggregateComplianceByConformancePacks"
)
DescribeAggregationAuthorizations = Action("DescribeAggregationAuthorizations")
DescribeComplianceByConfigRule = Action("DescribeComplianceByConfigRule")
DescribeComplianceByResource = Action("DescribeComplianceByResource")
DescribeConfigRuleEvaluationStatus = Action("DescribeConfigRuleEvaluationStatus")
DescribeConfigRules = Action("DescribeConfigRules")
DescribeConfigurationAggregatorSourcesStatus = Action(
    "DescribeConfigurationAggregatorSourcesStatus"
)
DescribeConfigurationAggregators = Action("DescribeConfigurationAggregators")
DescribeConfigurationRecorderStatus = Action("DescribeConfigurationRecorderStatus")
DescribeConfigurationRecorders = Action("DescribeConfigurationRecorders")
DescribeConformancePackCompliance = Action("DescribeConformancePackCompliance")
DescribeConformancePackStatus = Action("DescribeConformancePackStatus")
DescribeConformancePacks = Action("DescribeConformancePacks")
DescribeDeliveryChannelStatus = Action("DescribeDeliveryChannelStatus")
DescribeDeliveryChannels = Action("DescribeDeliveryChannels")
DescribeOrganizationConfigRuleStatuses = Action(
    "DescribeOrganizationConfigRuleStatuses"
)
DescribeOrganizationConfigRules = Action("DescribeOrganizationConfigRules")
DescribeOrganizationConformancePackStatuses = Action(
    "DescribeOrganizationConformancePackStatuses"
)
DescribeOrganizationConformancePacks = Action("DescribeOrganizationConformancePacks")
DescribePendingAggregationRequests = Action("DescribePendingAggregationRequests")
DescribeRemediationConfigurations = Action("DescribeRemediationConfigurations")
DescribeRemediationExceptions = Action("DescribeRemediationExceptions")
DescribeRemediationExecutionStatus = Action("DescribeRemediationExecutionStatus")
DescribeRetentionConfigurations = Action("DescribeRetentionConfigurations")
GetAggregateComplianceDetailsByConfigRule = Action(
    "GetAggregateComplianceDetailsByConfigRule"
)
GetAggregateConfigRuleComplianceSummary = Action(
    "GetAggregateConfigRuleComplianceSummary"
)
GetAggregateConformancePackComplianceSummary = Action(
    "GetAggregateConformancePackComplianceSummary"
)
GetAggregateDiscoveredResourceCounts = Action("GetAggregateDiscoveredResourceCounts")
GetAggregateResourceConfig = Action("GetAggregateResourceConfig")
GetComplianceDetailsByConfigRule = Action("GetComplianceDetailsByConfigRule")
GetComplianceDetailsByResource = Action("GetComplianceDetailsByResource")
GetComplianceSummaryByConfigRule = Action("GetComplianceSummaryByConfigRule")
GetComplianceSummaryByResourceType = Action("GetComplianceSummaryByResourceType")
GetConformancePackComplianceDetails = Action("GetConformancePackComplianceDetails")
GetConformancePackComplianceSummary = Action("GetConformancePackComplianceSummary")
GetDiscoveredResourceCounts = Action("GetDiscoveredResourceCounts")
GetOrganizationConfigRuleDetailedStatus = Action(
    "GetOrganizationConfigRuleDetailedStatus"
)
GetOrganizationConformancePackDetailedStatus = Action(
    "GetOrganizationConformancePackDetailedStatus"
)
GetResourceConfigHistory = Action("GetResourceConfigHistory")
GetResources = Action("GetResources")
GetStoredQuery = Action("GetStoredQuery")
GetTagKeys = Action("GetTagKeys")
ListAggregateDiscoveredResources = Action("ListAggregateDiscoveredResources")
ListDiscoveredResources = Action("ListDiscoveredResources")
ListStoredQueries = Action("ListStoredQueries")
ListTagsForResource = Action("ListTagsForResource")
PutAggregationAuthorization = Action("PutAggregationAuthorization")
PutConfigRule = Action("PutConfigRule")
PutConfigurationAggregator = Action("PutConfigurationAggregator")
PutConfigurationRecorder = Action("PutConfigurationRecorder")
PutConformancePack = Action("PutConformancePack")
PutDeliveryChannel = Action("PutDeliveryChannel")
PutEvaluations = Action("PutEvaluations")
PutExternalEvaluation = Action("PutExternalEvaluation")
PutOrganizationConfigRule = Action("PutOrganizationConfigRule")
PutOrganizationConformancePack = Action("PutOrganizationConformancePack")
PutRemediationConfigurations = Action("PutRemediationConfigurations")
PutRemediationExceptions = Action("PutRemediationExceptions")
PutResourceConfig = Action("PutResourceConfig")
PutRetentionConfiguration = Action("PutRetentionConfiguration")
PutStoredQuery = Action("PutStoredQuery")
SelectAggregateResourceConfig = Action("SelectAggregateResourceConfig")
SelectResourceConfig = Action("SelectResourceConfig")
StartConfigRulesEvaluation = Action("StartConfigRulesEvaluation")
StartConfigurationRecorder = Action("StartConfigurationRecorder")
StartRemediationExecution = Action("StartRemediationExecution")
StopConfigurationRecorder = Action("StopConfigurationRecorder")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Lookout for Vision"
prefix = "lookoutvision"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDataset = Action("CreateDataset")
CreateModel = Action("CreateModel")
CreateProject = Action("CreateProject")
DeleteDataset = Action("DeleteDataset")
DeleteModel = Action("DeleteModel")
DeleteProject = Action("DeleteProject")
DescribeDataset = Action("DescribeDataset")
DescribeModel = Action("DescribeModel")
DescribeProject = Action("DescribeProject")
DescribeTrialDetection = Action("DescribeTrialDetection")
DetectAnomalies = Action("DetectAnomalies")
ListDatasetEntries = Action("ListDatasetEntries")
ListModels = Action("ListModels")
ListProjects = Action("ListProjects")
ListTagsForResource = Action("ListTagsForResource")
ListTrialDetections = Action("ListTrialDetections")
StartModel = Action("StartModel")
StartTrialDetection = Action("StartTrialDetection")
StopModel = Action("StopModel")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDatasetEntries = Action("UpdateDatasetEntries")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Personalize"
prefix = "personalize"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateBatchInferenceJob = Action("CreateBatchInferenceJob")
CreateCampaign = Action("CreateCampaign")
CreateDataset = Action("CreateDataset")
CreateDatasetExportJob = Action("CreateDatasetExportJob")
CreateDatasetGroup = Action("CreateDatasetGroup")
CreateDatasetImportJob = Action("CreateDatasetImportJob")
CreateEventTracker = Action("CreateEventTracker")
CreateFilter = Action("CreateFilter")
CreateSchema = Action("CreateSchema")
CreateSolution = Action("CreateSolution")
CreateSolutionVersion = Action("CreateSolutionVersion")
DeleteCampaign = Action("DeleteCampaign")
DeleteDataset = Action("DeleteDataset")
DeleteDatasetGroup = Action("DeleteDatasetGroup")
DeleteEventTracker = Action("DeleteEventTracker")
DeleteFilter = Action("DeleteFilter")
DeleteSchema = Action("DeleteSchema")
DeleteSolution = Action("DeleteSolution")
DescribeAlgorithm = Action("DescribeAlgorithm")
DescribeBatchInferenceJob = Action("DescribeBatchInferenceJob")
DescribeCampaign = Action("DescribeCampaign")
DescribeDataset = Action("DescribeDataset")
DescribeDatasetExportJob = Action("DescribeDatasetExportJob")
DescribeDatasetGroup = Action("DescribeDatasetGroup")
DescribeDatasetImportJob = Action("DescribeDatasetImportJob")
DescribeEventTracker = Action("DescribeEventTracker")
DescribeFeatureTransformation = Action("DescribeFeatureTransformation")
DescribeFilter = Action("DescribeFilter")
DescribeRecipe = Action("DescribeRecipe")
DescribeSchema = Action("DescribeSchema")
DescribeSolution = Action("DescribeSolution")
DescribeSolutionVersion = Action("DescribeSolutionVersion")
GetPersonalizedRanking = Action("GetPersonalizedRanking")
GetRecommendations = Action("GetRecommendations")
GetSolutionMetrics = Action("GetSolutionMetrics")
ListBatchInferenceJobs = Action("ListBatchInferenceJobs")
ListCampaigns = Action("ListCampaigns")
ListDatasetExportJobs = Action("ListDatasetExportJobs")
ListDatasetGroups = Action("ListDatasetGroups")
ListDatasetImportJobs = Action("ListDatasetImportJobs")
ListDatasets = Action("ListDatasets")
ListEventTrackers = Action("ListEventTrackers")
ListFilters = Action("ListFilters")
ListRecipes = Action("ListRecipes")
ListSchemas = Action("ListSchemas")
ListSolutionVersions = Action("ListSolutionVersions")
ListSolutions = Action("ListSolutions")
PutEvents = Action("PutEvents")
PutItems = Action("PutItems")
PutUsers = Action("PutUsers")
StopSolutionVersionCreation = Action("StopSolutionVersionCreation")
UpdateCampaign = Action("UpdateCampaign")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS OpsWorks Configuration Management"
prefix = "opsworks-cm"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateNode = Action("AssociateNode")
CreateBackup = Action("CreateBackup")
CreateServer = Action("CreateServer")
DeleteBackup = Action("DeleteBackup")
DeleteServer = Action("DeleteServer")
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeBackups = Action("DescribeBackups")
DescribeEvents = Action("DescribeEvents")
DescribeNodeAssociationStatus = Action("DescribeNodeAssociationStatus")
DescribeServers = Action("DescribeServers")
DisassociateNode = Action("DisassociateNode")
ExportServerEngineAttribute = Action("ExportServerEngineAttribute")
ListTagsForResource = Action("ListTagsForResource")
RestoreServer = Action("RestoreServer")
StartMaintenance = Action("StartMaintenance")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateServer = Action("UpdateServer")
UpdateServerEngineAttributes = Action("UpdateServerEngineAttributes")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CloudWatch"
prefix = "cloudwatch"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DeleteAlarms = Action("DeleteAlarms")
DeleteAnomalyDetector = Action("DeleteAnomalyDetector")
DeleteDashboards = Action("DeleteDashboards")
DeleteInsightRules = Action("DeleteInsightRules")
DeleteMetricStream = Action("DeleteMetricStream")
DescribeAlarmHistory = Action("DescribeAlarmHistory")
DescribeAlarms = Action("DescribeAlarms")
DescribeAlarmsForMetric = Action("DescribeAlarmsForMetric")
DescribeAnomalyDetectors = Action("DescribeAnomalyDetectors")
DescribeInsightRules = Action("DescribeInsightRules")
DisableAlarmActions = Action("DisableAlarmActions")
DisableInsightRules = Action("DisableInsightRules")
EnableAlarmActions = Action("EnableAlarmActions")
EnableInsightRules = Action("EnableInsightRules")
GetDashboard = Action("GetDashboard")
GetInsightRuleReport = Action("GetInsightRuleReport")
GetMetricData = Action("GetMetricData")
GetMetricStatistics = Action("GetMetricStatistics")
GetMetricStream = Action("GetMetricStream")
GetMetricWidgetImage = Action("GetMetricWidgetImage")
ListDashboards = Action("ListDashboards")
ListMetricStreams = Action("ListMetricStreams")
ListMetrics = Action("ListMetrics")
ListTagsForResource = Action("ListTagsForResource")
PutAnomalyDetector = Action("PutAnomalyDetector")
PutCompositeAlarm = Action("PutCompositeAlarm")
PutDashboard = Action("PutDashboard")
PutInsightRule = Action("PutInsightRule")
PutMetricAlarm = Action("PutMetricAlarm")
PutMetricData = Action("PutMetricData")
PutMetricStream = Action("PutMetricStream")
SetAlarmState = Action("SetAlarmState")
StartMetricStreams = Action("StartMetricStreams")
StopMetricStreams = Action("StopMetricStreams")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Resource Access Manager"
prefix = "ram"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptResourceShareInvitation = Action("AcceptResourceShareInvitation")
AssociateResourceShare = Action("AssociateResourceShare")
AssociateResourceSharePermission = Action("AssociateResourceSharePermission")
CreateResourceShare = Action("CreateResourceShare")
DeleteResourceShare = Action("DeleteResourceShare")
DisassociateResourceShare = Action("DisassociateResourceShare")
DisassociateResourceSharePermission = Action("DisassociateResourceSharePermission")
EnableSharingWithAwsOrganization = Action("EnableSharingWithAwsOrganization")
GetPermission = Action("GetPermission")
GetResourcePolicies = Action("GetResourcePolicies")
GetResourceShareAssociations = Action("GetResourceShareAssociations")
GetResourceShareInvitations = Action("GetResourceShareInvitations")
GetResourceShares = Action("GetResourceShares")
ListPendingInvitationResources = Action("ListPendingInvitationResources")
ListPermissions = Action("ListPermissions")
ListPrincipals = Action("ListPrincipals")
ListResourceSharePermissions = Action("ListResourceSharePermissions")
ListResourceTypes = Action("ListResourceTypes")
ListResources = Action("ListResources")
PromoteResourceShareCreatedFromPolicy = Action("PromoteResourceShareCreatedFromPolicy")
RejectResourceShareInvitation = Action("RejectResourceShareInvitation")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateResourceShare = Action("UpdateResourceShare")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon DevOps Guru"
prefix = "devops-guru"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddNotificationChannel = Action("AddNotificationChannel")
DescribeAccountHealth = Action("DescribeAccountHealth")
DescribeAccountOverview = Action("DescribeAccountOverview")
DescribeAnomaly = Action("DescribeAnomaly")
DescribeFeedback = Action("DescribeFeedback")
DescribeInsight = Action("DescribeInsight")
DescribeResourceCollectionHealth = Action("DescribeResourceCollectionHealth")
DescribeServiceIntegration = Action("DescribeServiceIntegration")
GetCostEstimation = Action("GetCostEstimation")
GetResourceCollection = Action("GetResourceCollection")
ListAnomaliesForInsight = Action("ListAnomaliesForInsight")
ListEvents = Action("ListEvents")
ListInsights = Action("ListInsights")
ListNotificationChannels = Action("ListNotificationChannels")
ListRecommendations = Action("ListRecommendations")
PutFeedback = Action("PutFeedback")
RemoveNotificationChannel = Action("RemoveNotificationChannel")
SearchInsights = Action("SearchInsights")
StartCostEstimation = Action("StartCostEstimation")
UpdateResourceCollection = Action("UpdateResourceCollection")
UpdateServiceIntegration = Action("UpdateServiceIntegration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Route 53 Recovery Controls"
prefix = "route53-recovery-control-config"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCluster = Action("CreateCluster")
CreateControlPanel = Action("CreateControlPanel")
CreateRoutingControl = Action("CreateRoutingControl")
CreateSafetyRule = Action("CreateSafetyRule")
DeleteCluster = Action("DeleteCluster")
DeleteControlPanel = Action("DeleteControlPanel")
DeleteRoutingControl = Action("DeleteRoutingControl")
DeleteSafetyRule = Action("DeleteSafetyRule")
DescribeCluster = Action("DescribeCluster")
DescribeControlPanel = Action("DescribeControlPanel")
DescribeRoutingControl = Action("DescribeRoutingControl")
DescribeRoutingControlByName = Action("DescribeRoutingControlByName")
DescribeSafetyRule = Action("DescribeSafetyRule")
ListAssociatedRoute53HealthChecks = Action("ListAssociatedRoute53HealthChecks")
ListClusters = Action("ListClusters")
ListControlPanels = Action("ListControlPanels")
ListRoutingControls = Action("ListRoutingControls")
ListSafetyRules = Action("ListSafetyRules")
UpdateControlPanel = Action("UpdateControlPanel")
UpdateRoutingControl = Action("UpdateRoutingControl")
UpdateSafetyRule = Action("UpdateSafetyRule")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Cloud9"
prefix = "cloud9"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivateEC2Remote = Action("ActivateEC2Remote")
CreateEnvironmentEC2 = Action("CreateEnvironmentEC2")
CreateEnvironmentMembership = Action("CreateEnvironmentMembership")
CreateEnvironmentSSH = Action("CreateEnvironmentSSH")
CreateEnvironmentToken = Action("CreateEnvironmentToken")
DeleteEnvironment = Action("DeleteEnvironment")
DeleteEnvironmentMembership = Action("DeleteEnvironmentMembership")
DescribeEC2Remote = Action("DescribeEC2Remote")
DescribeEnvironmentMemberships = Action("DescribeEnvironmentMemberships")
DescribeEnvironmentStatus = Action("DescribeEnvironmentStatus")
DescribeEnvironments = Action("DescribeEnvironments")
DescribeSSHRemote = Action("DescribeSSHRemote")
GetEnvironmentConfig = Action("GetEnvironmentConfig")
GetEnvironmentSettings = Action("GetEnvironmentSettings")
GetMembershipSettings = Action("GetMembershipSettings")
GetUserPublicKey = Action("GetUserPublicKey")
GetUserSettings = Action("GetUserSettings")
ListEnvironments = Action("ListEnvironments")
ListTagsForResource = Action("ListTagsForResource")
ModifyTemporaryCredentialsOnEnvironmentEC2 = Action(
    "ModifyTemporaryCredentialsOnEnvironmentEC2"
)
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateEnvironment = Action("UpdateEnvironment")
UpdateEnvironmentMembership = Action("UpdateEnvironmentMembership")
UpdateEnvironmentSettings = Action("UpdateEnvironmentSettings")
UpdateMembershipSettings = Action("UpdateMembershipSettings")
UpdateSSHRemote = Action("UpdateSSHRemote")
UpdateUserSettings = Action("UpdateUserSettings")
ValidateEnvironmentName = Action("ValidateEnvironmentName")
